#
# spec file for package ceph
#
# Copyright (C) 2004-2017 The Ceph Project Developers. See COPYING file
# at the top-level directory of this distribution and at
# https://github.com/ceph/ceph/blob/master/COPYING
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon.
#
# This file is under the GNU Lesser General Public License, version 2.1
#
# Please submit bugfixes or comments via http://tracker.ceph.com/
#
%bcond_without ocf
%bcond_with cephfs_java
%if 0%{?suse_version}
%bcond_with ceph_test_package
%else
%bcond_without ceph_test_package
%endif
%bcond_with make_check
%ifarch s390 s390x
%bcond_with tcmalloc
%else
%bcond_without tcmalloc
%endif
%bcond_without lowmem_builder
%bcond_with minimal_debugging_information
%if 0%{?fedora} || 0%{?rhel}
%bcond_with ocf
%bcond_without selinux
%endif
%if 0%{?suse_version}
%bcond_without ocf
%if %{with ocf}
%global _with_ocf --with-ocf
%endif
%bcond_with selinux
%endif

# LTTng-UST enabled on Fedora, RHEL 6+, and SLE (not openSUSE)
%if 0%{?fedora} || 0%{?rhel} >= 6 || 0%{?suse_version}
%if ! 0%{?is_opensuse}
%ifarch x86_64 aarch64
%bcond_without lttng
%endif
%endif
%endif

%if %{with selinux}
# get selinux policy version
%{!?_selinux_policy_version: %global _selinux_policy_version %(sed -e 's,.*selinux-policy-\\([^/]*\\)/.*,\\1,' /usr/share/selinux/devel/policyhelp 2>/dev/null || echo 0.0.0)}
%endif

%{!?_udevrulesdir: %global _udevrulesdir /lib/udev/rules.d}
%{!?tmpfiles_create: %global tmpfiles_create systemd-tmpfiles --create}
%{!?python3_pkgversion: %global python3_pkgversion 3}

# unify libexec for all targets
%global _libexecdir %{_exec_prefix}/lib

# disable dwz which compresses the debuginfo
%global _find_debuginfo_dwz_opts %{nil}

#################################################################################
# main package definition
#################################################################################
Name:		ceph
Version:	12.2.5+git.1524775272.5e7ea8cf03
Release:	9.1
%if 0%{?fedora} || 0%{?rhel}
Epoch:		2
%endif

# define _epoch_prefix macro which will expand to the empty string if epoch is
# undefined
%global _epoch_prefix %{?epoch:%{epoch}:}

Summary:	User space components of the Ceph file system
License:	LGPL-2.1 and CC-BY-SA-3.0 and GPL-2.0 and BSL-1.0 and BSD-3-Clause and MIT
%if 0%{?suse_version}
Group:		System/Filesystems
%endif
URL:		http://ceph.com/
Source0:	ceph-12.2.5-407-g5e7ea8cf03.tar.bz2
# _insert_obs_source_lines_here
%if 0%{?suse_version}
%if 0%{?is_opensuse}
ExclusiveArch:  x86_64 aarch64 ppc64 ppc64le
%else
ExclusiveArch:  x86_64 aarch64 ppc64le s390x
%endif
%endif
#################################################################################
# dependencies that apply across all distro families
#################################################################################
Requires:       ceph-osd = %{_epoch_prefix}%{version}-%{release}
Requires:       ceph-mds = %{_epoch_prefix}%{version}-%{release}
Requires:       ceph-mgr = %{_epoch_prefix}%{version}-%{release}
Requires:       ceph-mon = %{_epoch_prefix}%{version}-%{release}
Requires(post):	binutils
%if 0%{with cephfs_java}
BuildRequires:	java-devel
BuildRequires:	sharutils
%endif
%if 0%{with selinux}
BuildRequires:	checkpolicy
BuildRequires:	selinux-policy-devel
BuildRequires:	/usr/share/selinux/devel/policyhelp
%endif
%if 0%{with make_check}
%if 0%{?fedora} || 0%{?rhel}
BuildRequires:	python-cherrypy
BuildRequires:	python-werkzeug
%endif
%if 0%{?suse_version}
BuildRequires:	python-CherryPy
BuildRequires:	python-Werkzeug
BuildRequires:	python-numpy-devel
%endif
BuildRequires:  python-coverage
BuildRequires:	python-pecan
BuildRequires:	socat
%endif
BuildRequires:	bc
BuildRequires:	gperf
BuildRequires:  cmake
BuildRequires:	cryptsetup
BuildRequires:	fuse-devel
BuildRequires:	gcc-c++
BuildRequires:	gdbm
%if 0%{with tcmalloc}
BuildRequires:	gperftools-devel >= 2.4
%endif
BuildRequires:  jq
BuildRequires:	leveldb-devel > 1.2
BuildRequires:	libaio-devel
BuildRequires:	libblkid-devel >= 2.17
BuildRequires:	libcurl-devel
BuildRequires:	libudev-devel
BuildRequires:	libtool
BuildRequires:	libxml2-devel
BuildRequires:	make
BuildRequires:	parted
BuildRequires:	perl
BuildRequires:	pkgconfig
BuildRequires:  procps
BuildRequires:	python
BuildRequires:	python-devel
BuildRequires:	python-nose
BuildRequires:	python-requests
BuildRequires:	python-virtualenv
BuildRequires:	snappy-devel
BuildRequires:	udev
BuildRequires:	util-linux
BuildRequires:	valgrind-devel
BuildRequires:	which
BuildRequires:	xfsprogs
BuildRequires:	xfsprogs-devel
BuildRequires:	xmlstarlet
BuildRequires:	yasm

#################################################################################
# distro-conditional dependencies
#################################################################################
%if 0%{?suse_version}
BuildRequires:  pkgconfig(systemd)
BuildRequires:	systemd-rpm-macros
BuildRequires:	systemd
%{?systemd_requires}
PreReq:		%fillup_prereq
BuildRequires:	net-tools
BuildRequires:	libbz2-devel
BuildRequires:  btrfsprogs
BuildRequires:	mozilla-nss-devel
BuildRequires:	keyutils-devel
BuildRequires:  libopenssl-devel
BuildRequires:  lsb-release
BuildRequires:  openldap2-devel
BuildRequires:	python-Cython
BuildRequires:	python-PrettyTable
BuildRequires:	python-Sphinx
BuildRequires:  rdma-core-devel
%endif
%if 0%{?fedora} || 0%{?rhel}
Requires:	systemd
BuildRequires:  boost-random
BuildRequires:	btrfs-progs
BuildRequires:	nss-devel
BuildRequires:	keyutils-libs-devel
BuildRequires:	libibverbs-devel
BuildRequires:  openldap-devel
BuildRequires:  openssl-devel
BuildRequires:  redhat-lsb-core
BuildRequires:	Cython
BuildRequires:	python-prettytable
BuildRequires:	python-sphinx
%endif
# python34-... for RHEL, python3-... for all other supported distros
%if 0%{?rhel}
BuildRequires:	python34-devel
BuildRequires:	python34-setuptools
BuildRequires:	python34-Cython
%else
BuildRequires:	python3-devel
BuildRequires:	python3-setuptools
BuildRequires:	python3-Cython
%endif
# lttng and babeltrace for rbd-replay-prep
%if %{with lttng}
%if 0%{?fedora} || 0%{?rhel}
BuildRequires:	lttng-ust-devel
BuildRequires:	libbabeltrace-devel
%endif
%if 0%{?suse_version}
BuildRequires:	lttng-ust-devel
BuildRequires:  babeltrace-devel
%endif
%endif
%if 0%{?suse_version}
BuildRequires:	libexpat-devel
%endif
%if 0%{?rhel} || 0%{?fedora}
BuildRequires:	expat-devel
%endif
#hardened-cc1
%if 0%{?fedora} || 0%{?rhel}
BuildRequires:  redhat-rpm-config
%endif

%description
Ceph is a massively scalable, open-source, distributed storage system that runs
on commodity hardware and delivers object, block and file system storage.


#################################################################################
# subpackages
#################################################################################
%package base
Summary:       Ceph Base Package
%if 0%{?suse_version}
Group:         System/Filesystems
%endif
Requires:      ceph-common = %{_epoch_prefix}%{version}-%{release}
Requires:      librbd1 = %{_epoch_prefix}%{version}-%{release}
Requires:      librados2 = %{_epoch_prefix}%{version}-%{release}
Requires:      libcephfs2 = %{_epoch_prefix}%{version}-%{release}
Requires:      librgw2 = %{_epoch_prefix}%{version}-%{release}
%if 0%{with selinux}
Requires:      ceph-selinux = %{_epoch_prefix}%{version}-%{release}
%endif
Requires:      python
Requires:      python-requests
Requires:      python-setuptools
Requires:      grep
Requires:      xfsprogs
Requires:      logrotate
Requires:      util-linux
Requires:      cryptsetup
Requires:      findutils
Requires:      psmisc
Requires:      which
%if 0%{?suse_version}
Recommends:    ntp-daemon
Provides:      libxio = 1.7
Obsoletes:     libxio <= 1.7
%endif
%description base
Base is the package that includes all the files shared amongst ceph servers

%package -n ceph-common
Summary:	Ceph Common
%if 0%{?suse_version}
Group:		System/Filesystems
%endif
Requires:	librbd1 = %{_epoch_prefix}%{version}-%{release}
Requires:	librados2 = %{_epoch_prefix}%{version}-%{release}
Requires:	libcephfs2 = %{_epoch_prefix}%{version}-%{release}
Requires:	python-rados = %{_epoch_prefix}%{version}-%{release}
Requires:	python-rbd = %{_epoch_prefix}%{version}-%{release}
Requires:	python-cephfs = %{_epoch_prefix}%{version}-%{release}
Requires:	python-rgw = %{_epoch_prefix}%{version}-%{release}
%if 0%{?fedora} || 0%{?rhel}
Requires:	python-prettytable
%endif
%if 0%{?suse_version}
Requires:	python-PrettyTable
Provides:       libxio = 1.7
Obsoletes:      libxio <= 1.7
%endif
Requires:	python-requests
%{?systemd_requires}
%if 0%{?suse_version}
PreReq:         permissions
Requires(pre):	shadow
%endif
%description -n ceph-common
Common utilities to mount and interact with a ceph storage cluster.
Comprised of files that are common to Ceph clients and servers.

%package mds
Summary:	Ceph Metadata Server Daemon
%if 0%{?suse_version}
Group:		System/Filesystems
%endif
Requires:	ceph-base = %{_epoch_prefix}%{version}-%{release}
%description mds
ceph-mds is the metadata server daemon for the Ceph distributed file system.
One or more instances of ceph-mds collectively manage the file system
namespace, coordinating access to the shared OSD cluster.

%package mon
Summary:	Ceph Monitor Daemon
%if 0%{?suse_version}
Group:		System/Filesystems
%endif
Requires:	ceph-base = %{_epoch_prefix}%{version}-%{release}
# For ceph-rest-api
%if 0%{?fedora} || 0%{?rhel}
Requires:      python-flask
%endif
%if 0%{?suse_version}
Requires:      python-Flask
%endif
%description mon
ceph-mon is the cluster monitor daemon for the Ceph distributed file
system. One or more instances of ceph-mon form a Paxos part-time
parliament cluster that provides extremely reliable and durable storage
of cluster membership, configuration, and state.

%package mgr
Summary:        Ceph Manager Daemon
%if 0%{?suse_version}
Group:          System/Filesystems
%endif
Requires:       ceph-base = %{_epoch_prefix}%{version}-%{release}
%if 0%{?fedora} || 0%{?rhel}
Requires:       python-cherrypy
Requires:       python-jinja2
Requires:       python-werkzeug
Requires:       pyOpenSSL
%endif
%if 0%{?suse_version}
Requires: 	python-CherryPy
Requires:       python-Jinja2
Requires:       python-Werkzeug
Requires:       python-pyOpenSSL
%endif
Requires:       python-pecan
%description mgr
ceph-mgr enables python modules that provide services (such as the REST
module derived from Calamari) and expose CLI hooks.  ceph-mgr gathers
the cluster maps, the daemon metadata, and performance counters, and
exposes all these to the python modules.

%package fuse
Summary:	Ceph fuse-based client
%if 0%{?suse_version}
Group:		System/Filesystems
%endif
Requires:       fuse
%description fuse
FUSE based client for Ceph distributed network file system

%package -n rbd-fuse
Summary:	Ceph fuse-based client
%if 0%{?suse_version}
Group:		System/Filesystems
%endif
Requires:	librados2 = %{_epoch_prefix}%{version}-%{release}
Requires:	librbd1 = %{_epoch_prefix}%{version}-%{release}
%description -n rbd-fuse
FUSE based client to map Ceph rbd images to files

%package -n rbd-mirror
Summary:	Ceph daemon for mirroring RBD images
%if 0%{?suse_version}
Group:		System/Filesystems
%endif
Requires:	ceph-common = %{_epoch_prefix}%{version}-%{release}
Requires:	librados2 = %{_epoch_prefix}%{version}-%{release}
%description -n rbd-mirror
Daemon for mirroring RBD images between Ceph clusters, streaming
changes asynchronously.

%package -n rbd-nbd
Summary:	Ceph RBD client base on NBD
%if 0%{?suse_version}
Group:		System/Filesystems
%endif
Requires:	librados2 = %{_epoch_prefix}%{version}-%{release}
Requires:	librbd1 = %{_epoch_prefix}%{version}-%{release}
%description -n rbd-nbd
NBD based client to map Ceph rbd images to local device

%package radosgw
Summary:	Rados REST gateway
%if 0%{?suse_version}
Group:		System/Filesystems
%endif
Requires:	ceph-common = %{_epoch_prefix}%{version}-%{release}
%if 0%{with selinux}
Requires:	ceph-selinux = %{_epoch_prefix}%{version}-%{release}
%endif
Requires:	librados2 = %{_epoch_prefix}%{version}-%{release}
Requires:	librgw2 = %{_epoch_prefix}%{version}-%{release}
%if 0%{?rhel} || 0%{?fedora}
Requires:	mailcap
%endif
%description radosgw
RADOS is a distributed object store used by the Ceph distributed
storage system.  This package provides a REST gateway to the
object store that aims to implement a superset of Amazon's S3
service as well as the OpenStack Object Storage ("Swift") API.

%if %{with ocf}
%package resource-agents
Summary:	OCF-compliant resource agents for Ceph daemons
%if 0%{?suse_version}
Group:		System/Filesystems
%endif
Requires:	ceph-base = %{_epoch_prefix}%{version}
Requires:	resource-agents
%description resource-agents
Resource agents for monitoring and managing Ceph daemons
under Open Cluster Framework (OCF) compliant resource
managers such as Pacemaker.
%endif

%package osd
Summary:	Ceph Object Storage Daemon
%if 0%{?suse_version}
Group:		System/Filesystems
%endif
Requires:	ceph-base = %{_epoch_prefix}%{version}-%{release}
# for sgdisk, used by ceph-disk
%if 0%{?fedora} || 0%{?rhel}
Requires:	gdisk
%endif
%if 0%{?suse_version}
Requires:	gptfdisk
%endif
Requires:	parted
Requires:	lvm2
%description osd
ceph-osd is the object storage daemon for the Ceph distributed file
system.  It is responsible for storing objects on a local file system
and providing access to them over the network.

%package -n librados2
Summary:	RADOS distributed object store client library
%if 0%{?suse_version}
Group:		System/Libraries
%endif
%if 0%{?rhel} || 0%{?fedora}
Obsoletes:	ceph-libs < %{_epoch_prefix}%{version}-%{release}
%endif
%description -n librados2
RADOS is a reliable, autonomic distributed object storage cluster
developed as part of the Ceph distributed storage system. This is a
shared library allowing applications to access the distributed object
store using a simple file-like interface.

%package -n librados-devel
Summary:	RADOS headers
%if 0%{?suse_version}
Group:		Development/Libraries/C and C++
%endif
Requires:	librados2 = %{_epoch_prefix}%{version}-%{release}
Obsoletes:	ceph-devel < %{_epoch_prefix}%{version}-%{release}
Provides:	librados2-devel = %{_epoch_prefix}%{version}-%{release}
Obsoletes:	librados2-devel < %{_epoch_prefix}%{version}-%{release}
%description -n librados-devel
This package contains libraries and headers needed to develop programs
that use RADOS object store.

%package -n librgw2
Summary:	RADOS gateway client library
%if 0%{?suse_version}
Group:		System/Libraries
%endif
Requires:	librados2 = %{_epoch_prefix}%{version}-%{release}
%description -n librgw2
This package provides a library implementation of the RADOS gateway
(distributed object store with S3 and Swift personalities).

%package -n librgw-devel
Summary:	RADOS gateway client library
%if 0%{?suse_version}
Group:		Development/Libraries/C and C++
%endif
Requires:	librados-devel = %{_epoch_prefix}%{version}-%{release}
Requires:	librgw2 = %{_epoch_prefix}%{version}-%{release}
Provides:	librgw2-devel = %{_epoch_prefix}%{version}-%{release}
Obsoletes:	librgw2-devel < %{_epoch_prefix}%{version}-%{release}
%description -n librgw-devel
This package contains libraries and headers needed to develop programs
that use RADOS gateway client library.

%package -n python-rgw
Summary:	Python 2 libraries for the RADOS gateway
%if 0%{?suse_version}
Group:		Development/Languages/Python
%endif
Requires:	librgw2 = %{_epoch_prefix}%{version}-%{release}
Requires:	python-rados = %{_epoch_prefix}%{version}-%{release}
Obsoletes:	python-ceph < %{_epoch_prefix}%{version}-%{release}
%description -n python-rgw
This package contains Python 2 libraries for interacting with Cephs RADOS
gateway.

%package -n python%{python3_pkgversion}-rgw
Summary:	Python 3 libraries for the RADOS gateway
%if 0%{?suse_version}
Group:		Development/Languages/Python
%endif
Requires:	librgw2 = %{_epoch_prefix}%{version}-%{release}
Requires:	python%{python3_pkgversion}-rados = %{_epoch_prefix}%{version}-%{release}
%description -n python%{python3_pkgversion}-rgw
This package contains Python 3 libraries for interacting with Cephs RADOS
gateway.

%package -n python-rados
Summary:	Python 2 libraries for the RADOS object store
%if 0%{?suse_version}
Group:		Development/Languages/Python
%endif
Requires:	librados2 = %{_epoch_prefix}%{version}-%{release}
Obsoletes:	python-ceph < %{_epoch_prefix}%{version}-%{release}
%description -n python-rados
This package contains Python 2 libraries for interacting with Cephs RADOS
object store.

%package -n python%{python3_pkgversion}-rados
Summary:	Python 3 libraries for the RADOS object store
%if 0%{?suse_version}
Group:		Development/Languages/Python
%endif
Requires:	python%{python3_pkgversion}
Requires:	librados2 = %{_epoch_prefix}%{version}-%{release}
%description -n python%{python3_pkgversion}-rados
This package contains Python 3 libraries for interacting with Cephs RADOS
object store.

%package -n libradosstriper1
Summary:	RADOS striping interface
%if 0%{?suse_version}
Group:		System/Libraries
%endif
Requires:	librados2 = %{_epoch_prefix}%{version}-%{release}
%description -n libradosstriper1
Striping interface built on top of the rados library, allowing
to stripe bigger objects onto several standard rados objects using
an interface very similar to the rados one.

%package -n libradosstriper-devel
Summary:	RADOS striping interface headers
%if 0%{?suse_version}
Group:		Development/Libraries/C and C++
%endif
Requires:	libradosstriper1 = %{_epoch_prefix}%{version}-%{release}
Requires:	librados-devel = %{_epoch_prefix}%{version}-%{release}
Obsoletes:	ceph-devel < %{_epoch_prefix}%{version}-%{release}
Provides:	libradosstriper1-devel = %{_epoch_prefix}%{version}-%{release}
Obsoletes:	libradosstriper1-devel < %{_epoch_prefix}%{version}-%{release}
%description -n libradosstriper-devel
This package contains libraries and headers needed to develop programs
that use RADOS striping interface.

%package -n librbd1
Summary:	RADOS block device client library
%if 0%{?suse_version}
Group:		System/Libraries
%endif
Requires:	librados2 = %{_epoch_prefix}%{version}-%{release}
%if 0%{?suse_version}
Requires(post): coreutils
%endif
%if 0%{?rhel} || 0%{?fedora}
Obsoletes:	ceph-libs < %{_epoch_prefix}%{version}-%{release}
%endif
%description -n librbd1
RBD is a block device striped across multiple distributed objects in
RADOS, a reliable, autonomic distributed object storage cluster
developed as part of the Ceph distributed storage system. This is a
shared library allowing applications to manage these block devices.

%package -n librbd-devel
Summary:	RADOS block device headers
%if 0%{?suse_version}
Group:		Development/Libraries/C and C++
%endif
Requires:	librbd1 = %{_epoch_prefix}%{version}-%{release}
Requires:	librados-devel = %{_epoch_prefix}%{version}-%{release}
Obsoletes:	ceph-devel < %{_epoch_prefix}%{version}-%{release}
Provides:	librbd1-devel = %{_epoch_prefix}%{version}-%{release}
Obsoletes:	librbd1-devel < %{_epoch_prefix}%{version}-%{release}
%description -n librbd-devel
This package contains libraries and headers needed to develop programs
that use RADOS block device.

%package -n python-rbd
Summary:	Python 2 libraries for the RADOS block device
%if 0%{?suse_version}
Group:		Development/Languages/Python
%endif
Requires:	librbd1 = %{_epoch_prefix}%{version}-%{release}
Requires:	python-rados = %{_epoch_prefix}%{version}-%{release}
Obsoletes:	python-ceph < %{_epoch_prefix}%{version}-%{release}
%description -n python-rbd
This package contains Python 2 libraries for interacting with Cephs RADOS
block device.

%package -n python%{python3_pkgversion}-rbd
Summary:	Python 3 libraries for the RADOS block device
%if 0%{?suse_version}
Group:		Development/Languages/Python
%endif
Requires:	librbd1 = %{_epoch_prefix}%{version}-%{release}
Requires:	python%{python3_pkgversion}-rados = %{_epoch_prefix}%{version}-%{release}
%description -n python%{python3_pkgversion}-rbd
This package contains Python 3 libraries for interacting with Cephs RADOS
block device.

%package -n libcephfs2
Summary:	Ceph distributed file system client library
%if 0%{?suse_version}
Group:		System/Libraries
%endif
Obsoletes:	libcephfs1
%if 0%{?rhel} || 0%{?fedora}
Obsoletes:	ceph-libs < %{_epoch_prefix}%{version}-%{release}
Obsoletes:	ceph-libcephfs
%endif
%description -n libcephfs2
Ceph is a distributed network file system designed to provide excellent
performance, reliability, and scalability. This is a shared library
allowing applications to access a Ceph distributed file system via a
POSIX-like interface.

%package -n libcephfs-devel
Summary:	Ceph distributed file system headers
%if 0%{?suse_version}
Group:		Development/Libraries/C and C++
%endif
Requires:	libcephfs2 = %{_epoch_prefix}%{version}-%{release}
Requires:	librados-devel = %{_epoch_prefix}%{version}-%{release}
Obsoletes:	ceph-devel < %{_epoch_prefix}%{version}-%{release}
Provides:	libcephfs2-devel = %{_epoch_prefix}%{version}-%{release}
Obsoletes:	libcephfs2-devel < %{_epoch_prefix}%{version}-%{release}
%description -n libcephfs-devel
This package contains libraries and headers needed to develop programs
that use Cephs distributed file system.

%package -n python-cephfs
Summary:	Python 2 libraries for Ceph distributed file system
%if 0%{?suse_version}
Group:		Development/Languages/Python
%endif
Requires:	libcephfs2 = %{_epoch_prefix}%{version}-%{release}
%if 0%{?suse_version}
Recommends: python-rados = %{_epoch_prefix}%{version}-%{release}
%endif
Obsoletes:	python-ceph < %{_epoch_prefix}%{version}-%{release}
%description -n python-cephfs
This package contains Python 2 libraries for interacting with Cephs distributed
file system.

%package -n python%{python3_pkgversion}-cephfs
Summary:	Python 3 libraries for Ceph distributed file system
%if 0%{?suse_version}
Group:		Development/Languages/Python
%endif
Requires:	libcephfs2 = %{_epoch_prefix}%{version}-%{release}
Requires:	python%{python3_pkgversion}-rados = %{_epoch_prefix}%{version}-%{release}
%description -n python%{python3_pkgversion}-cephfs
This package contains Python 3 libraries for interacting with Cephs distributed
file system.

%package -n python%{python3_pkgversion}-ceph-argparse
Summary:	Python 3 utility libraries for Ceph CLI
%if 0%{?suse_version}
Group:		Development/Languages/Python
%endif
%description -n python%{python3_pkgversion}-ceph-argparse
This package contains types and routines for Python 3 used by the Ceph CLI as
well as the RESTful interface. These have to do with querying the daemons for
command-description information, validating user command input against those
descriptions, and submitting the command to the appropriate daemon.

%if 0%{with ceph_test_package}
%package -n ceph-test
Summary:	Ceph benchmarks and test tools
%if 0%{?suse_version}
Group:		System/Benchmark
%endif
Requires:	ceph-common
Requires:	xmlstarlet
Requires:	jq
Requires:	socat
%description -n ceph-test
This package contains Ceph benchmarks and test tools.
%endif

%if 0%{with cephfs_java}

%package -n libcephfs_jni1
Summary:	Java Native Interface library for CephFS Java bindings
%if 0%{?suse_version}
Group:		System/Libraries
%endif
Requires:	java
Requires:	libcephfs2 = %{_epoch_prefix}%{version}-%{release}
%description -n libcephfs_jni1
This package contains the Java Native Interface library for CephFS Java
bindings.

%package -n libcephfs_jni-devel
Summary:	Development files for CephFS Java Native Interface library
%if 0%{?suse_version}
Group:		Development/Libraries/Java
%endif
Requires:	java
Requires:	libcephfs_jni1 = %{_epoch_prefix}%{version}-%{release}
Obsoletes:	ceph-devel < %{_epoch_prefix}%{version}-%{release}
Provides:	libcephfs_jni1-devel = %{_epoch_prefix}%{version}-%{release}
Obsoletes:	libcephfs_jni1-devel < %{_epoch_prefix}%{version}-%{release}
%description -n libcephfs_jni-devel
This package contains the development files for CephFS Java Native Interface
library.

%package -n cephfs-java
Summary:	Java libraries for the Ceph File System
%if 0%{?suse_version}
Group:		System/Libraries
%endif
Requires:	java
Requires:	libcephfs_jni1 = %{_epoch_prefix}%{version}-%{release}
Requires:       junit
BuildRequires:  junit
%description -n cephfs-java
This package contains the Java libraries for the Ceph File System.

%endif

%package -n rados-objclass-devel
Summary:        RADOS object class development kit
Group:          Development/Libraries
Requires:       librados2-devel = %{_epoch_prefix}%{version}-%{release}
%description -n rados-objclass-devel
This package contains libraries and headers needed to develop RADOS object
class plugins.

%if 0%{with selinux}

%package selinux
Summary:	SELinux support for Ceph MON, OSD and MDS
%if 0%{?suse_version}
Group:		System/Filesystems
%endif
Requires:	ceph-base = %{_epoch_prefix}%{version}-%{release}
Requires:	policycoreutils, libselinux-utils
Requires(post):	ceph-base = %{_epoch_prefix}%{version}-%{release}
Requires(post): selinux-policy-base >= %{_selinux_policy_version}, policycoreutils, gawk
Requires(postun): policycoreutils
%description selinux
This package contains SELinux support for Ceph MON, OSD and MDS. The package
also performs file-system relabelling which can take a long time on heavily
populated file-systems.

%endif

%package -n python-ceph-compat
Summary:	Compatibility package for Cephs python libraries
%if 0%{?suse_version}
Group:		Development/Languages/Python
%endif
Obsoletes:	python-ceph
Requires:	python-rados = %{_epoch_prefix}%{version}-%{release}
Requires:	python-rbd = %{_epoch_prefix}%{version}-%{release}
Requires:	python-cephfs = %{_epoch_prefix}%{version}-%{release}
Requires:	python-rgw = %{_epoch_prefix}%{version}-%{release}
Provides:	python-ceph
%description -n python-ceph-compat
This is a compatibility package to accommodate python-ceph split into
python-rados, python-rbd, python-rgw and python-cephfs. Packages still
depending on python-ceph should be fixed to depend on python-rados,
python-rbd, python-rgw or python-cephfs instead.

#################################################################################
# common
#################################################################################
%prep
%autosetup -p1 -n ceph-12.2.5-407-g5e7ea8cf03

%build
%if 0%{with cephfs_java}
# Find jni.h
for i in /usr/{lib64,lib}/jvm/java/include{,/linux}; do
    [ -d $i ] && java_inc="$java_inc -I$i"
done
%endif

%if %{with lowmem_builder}
RPM_OPT_FLAGS="$RPM_OPT_FLAGS --param ggc-min-expand=20 --param ggc-min-heapsize=32768"
%endif
%if %{with minimal_debugging_information}
RPM_OPT_FLAGS="`echo $RPM_OPT_FLAGS | sed -e 's/^-g /-g1 /g' -e 's/ -g / -g1 /g' -e 's/ -g$/ -g1/g'`"
%endif
export RPM_OPT_FLAGS=`echo $RPM_OPT_FLAGS | sed -e 's/i386/i486/'`

export CPPFLAGS="$java_inc"
export CFLAGS="$RPM_OPT_FLAGS"
export CXXFLAGS="$RPM_OPT_FLAGS"

env | sort

%if %{with lowmem_builder}
%if 0%{?jobs} > 8
%define _smp_mflags -j8
%endif
%endif

# unlimit _smp_mflags in system macro if not set above
%define _smp_ncpus_max 0
# extract the number of processors for use with cmake
%define _smp_ncpus %(echo %{_smp_mflags} | sed 's/-j//')

mkdir build
cd build
cmake .. \
    -DCMAKE_INSTALL_PREFIX=%{_prefix} \
    -DCMAKE_INSTALL_LIBDIR=%{_libdir} \
    -DCMAKE_INSTALL_LIBEXECDIR=%{_libexecdir} \
    -DCMAKE_INSTALL_LOCALSTATEDIR=%{_localstatedir} \
    -DCMAKE_INSTALL_SYSCONFDIR=%{_sysconfdir} \
    -DCMAKE_INSTALL_MANDIR=%{_mandir} \
    -DCMAKE_INSTALL_DOCDIR=%{_docdir}/ceph \
    -DCMAKE_INSTALL_INCLUDEDIR=%{_includedir} \
    -DWITH_EMBEDDED=OFF \
    -DWITH_MANPAGE=ON \
    -DWITH_PYTHON3=ON \
    -DWITH_SYSTEMD=ON \
%if 0%{?rhel} && ! 0%{?centos}
    -DWITH_SUBMAN=ON \
%endif
%if 0%{without ceph_test_package}
    -DWITH_TESTS=OFF \
%endif
%if 0%{with cephfs_java}
    -DWITH_CEPHFS_JAVA=ON \
%endif
%if 0%{with selinux}
    -DWITH_SELINUX=ON \
%endif
%if %{with lttng}
    -DWITH_LTTNG=ON \
    -DWITH_BABELTRACE=ON \
%else
    -DWITH_LTTNG=OFF \
    -DWITH_BABELTRACE=OFF \
%endif
    $CEPH_EXTRA_CMAKE_ARGS \
%if 0%{with ocf}
    -DWITH_OCF=ON \
%endif
%ifarch aarch64 armv7hl mips mipsel ppc ppc64 ppc64le %{ix86} x86_64
    -DWITH_BOOST_CONTEXT=ON \
%else
    -DWITH_BOOST_CONTEXT=OFF \
%endif
    -DBOOST_J=%{_smp_ncpus}

# Parallel build settings ...
PARALLEL_BUILD=%{?_smp_mflags}
lo_jobs="%{?jobs:%{jobs}}"
%ifarch %arm
    %if ! 0%{?qemu_user_space_build:1}
        # native hardware is not that powerful
        lo_jobs="1"
    %endif
%endif
# do not eat all memory
echo "Available memory:"
free
echo "System limits:"
ulimit -a
lo_jobs_reduced=
if test -n "$lo_jobs" -a "$lo_jobs" -gt 1 ; then
    mem_per_process=1700
    max_mem=$(LANG=C free -t -m | sed -n "s|^Mem: *\([0-9]*\).*$|\1|p")
    max_jobs="$(($max_mem / $mem_per_process))"
    test "$lo_jobs" -gt "$max_jobs" && lo_jobs="$max_jobs" && lo_jobs_reduced="yes" && echo "Warning: Reducing build parallelism to -j$max_jobs because of memory limits"
    test "$lo_jobs" -le 0 && lo_jobs=1 && echo "Warning: Not using parallel build at all because of memory limits"
fi
# run make
if test -n "$lo_jobs" ; then
  PARALLEL_BUILD="-j$lo_jobs"
fi

make "$PARALLEL_BUILD"


%if 0%{with make_check}
%check
# run in-tree unittests
cd build
ctest %{?_smp_mflags}

%endif



%install
pushd build
make DESTDIR=%{buildroot} install
# we have dropped sysvinit bits
rm -f %{buildroot}/%{_sysconfdir}/init.d/ceph
popd
install -m 0644 -D src/etc-rbdmap %{buildroot}%{_sysconfdir}/ceph/rbdmap
%if 0%{?fedora} || 0%{?rhel}
install -m 0644 -D etc/sysconfig/ceph %{buildroot}%{_sysconfdir}/sysconfig/ceph
%endif
%if 0%{?suse_version}
install -m 0644 -D etc/sysconfig/ceph %{buildroot}%{_localstatedir}/adm/fillup-templates/sysconfig.%{name}
%endif
install -m 0644 -D systemd/ceph.tmpfiles.d %{buildroot}%{_tmpfilesdir}/ceph-common.conf
install -m 0755 -D systemd/ceph %{buildroot}%{_sbindir}/rcceph
install -m 0644 -D systemd/50-ceph.preset %{buildroot}%{_libexecdir}/systemd/system-preset/50-ceph.preset
mkdir -p %{buildroot}%{_sbindir}
install -m 0644 -D src/logrotate.conf %{buildroot}%{_sysconfdir}/logrotate.d/ceph
chmod 0644 %{buildroot}%{_docdir}/ceph/sample.ceph.conf
install -m 0644 -D COPYING %{buildroot}%{_docdir}/ceph/COPYING
install -m 0644 -D etc/sysctl/90-ceph-osd.conf %{buildroot}%{_sysctldir}/90-ceph-osd.conf

# firewall templates and /sbin/mount.ceph symlink
%if 0%{?suse_version}
install -m 0644 -D etc/sysconfig/SuSEfirewall2.d/services/ceph-mon %{buildroot}%{_sysconfdir}/sysconfig/SuSEfirewall2.d/services/ceph-mon
install -m 0644 -D etc/sysconfig/SuSEfirewall2.d/services/ceph-osd-mds %{buildroot}%{_sysconfdir}/sysconfig/SuSEfirewall2.d/services/ceph-osd-mds
mkdir -p %{buildroot}/sbin
ln -sf %{_sbindir}/mount.ceph %{buildroot}/sbin/mount.ceph
%endif

# udev rules
install -m 0644 -D udev/50-rbd.rules %{buildroot}%{_udevrulesdir}/50-rbd.rules
install -m 0644 -D udev/60-ceph-by-parttypeuuid.rules %{buildroot}%{_udevrulesdir}/60-ceph-by-parttypeuuid.rules
install -m 0644 -D udev/95-ceph-osd.rules %{buildroot}%{_udevrulesdir}/95-ceph-osd.rules

#set up placeholder directories
mkdir -p %{buildroot}%{_sysconfdir}/ceph
mkdir -p %{buildroot}%{_localstatedir}/run/ceph
mkdir -p %{buildroot}%{_localstatedir}/log/ceph
mkdir -p %{buildroot}%{_localstatedir}/lib/ceph/tmp
mkdir -p %{buildroot}%{_localstatedir}/lib/ceph/mon
mkdir -p %{buildroot}%{_localstatedir}/lib/ceph/osd
mkdir -p %{buildroot}%{_localstatedir}/lib/ceph/mds
mkdir -p %{buildroot}%{_localstatedir}/lib/ceph/mgr
mkdir -p %{buildroot}%{_localstatedir}/lib/ceph/radosgw
mkdir -p %{buildroot}%{_localstatedir}/lib/ceph/bootstrap-osd
mkdir -p %{buildroot}%{_localstatedir}/lib/ceph/bootstrap-mds
mkdir -p %{buildroot}%{_localstatedir}/lib/ceph/bootstrap-rgw
mkdir -p %{buildroot}%{_localstatedir}/lib/ceph/bootstrap-mgr
mkdir -p %{buildroot}%{_localstatedir}/lib/ceph/bootstrap-rbd

%if 0%{?suse_version}
# create __pycache__ directories and their contents
%py3_compile %{buildroot}%{python3_sitelib}
%endif

%clean
rm -rf %{buildroot}

#################################################################################
# files and systemd scriptlets
#################################################################################
%files

%files base
%{_bindir}/crushtool
%{_bindir}/monmaptool
%{_bindir}/osdmaptool
%{_bindir}/ceph-kvstore-tool
%{_bindir}/ceph-run
%{_bindir}/ceph-dencoder
%{_bindir}/ceph-detect-init
%{_bindir}/cephfs-data-scan
%{_bindir}/cephfs-journal-tool
%{_bindir}/cephfs-table-tool
%{_libexecdir}/systemd/system-preset/50-ceph.preset
%{_sbindir}/ceph-create-keys
%{_sbindir}/ceph-disk
%{_sbindir}/rcceph
%dir %{_libexecdir}/ceph
%{_libexecdir}/ceph/ceph_common.sh
%dir %{_libdir}/rados-classes
%{_libdir}/rados-classes/*
%dir %{_libdir}/ceph
%dir %{_libdir}/ceph/erasure-code
%{_libdir}/ceph/erasure-code/libec_*.so*
%dir %{_libdir}/ceph/compressor
%{_libdir}/ceph/compressor/libceph_*.so*
%ifarch x86_64
%dir %{_libdir}/ceph/crypto
%{_libdir}/ceph/crypto/libceph_*.so*
%endif
%if %{with lttng}
%{_libdir}/libos_tp.so*
%{_libdir}/libosd_tp.so*
%endif
%config(noreplace) %{_sysconfdir}/logrotate.d/ceph
%if 0%{?fedora} || 0%{?rhel}
%config(noreplace) %{_sysconfdir}/sysconfig/ceph
%endif
%if 0%{?suse_version}
%{_localstatedir}/adm/fillup-templates/sysconfig.*
%config %{_sysconfdir}/sysconfig/SuSEfirewall2.d/services/ceph-mon
%config %{_sysconfdir}/sysconfig/SuSEfirewall2.d/services/ceph-osd-mds
%endif
%{_unitdir}/ceph-disk@.service
%{_unitdir}/ceph.target
%{python_sitelib}/ceph_detect_init*
%{python_sitelib}/ceph_disk*
%dir %{python_sitelib}/ceph_volume
%{python_sitelib}/ceph_volume/*
%{python_sitelib}/ceph_volume-*
%{_mandir}/man8/ceph-deploy.8*
%{_mandir}/man8/ceph-detect-init.8*
%{_mandir}/man8/ceph-create-keys.8*
%{_mandir}/man8/ceph-disk.8*
%{_mandir}/man8/ceph-run.8*
%{_mandir}/man8/crushtool.8*
%{_mandir}/man8/osdmaptool.8*
%{_mandir}/man8/monmaptool.8*
%{_mandir}/man8/ceph-kvstore-tool.8*
#set up placeholder directories
%attr(750,ceph,ceph) %dir %{_localstatedir}/lib/ceph/tmp
%attr(750,ceph,ceph) %dir %{_localstatedir}/lib/ceph/bootstrap-osd
%attr(750,ceph,ceph) %dir %{_localstatedir}/lib/ceph/bootstrap-mds
%attr(750,ceph,ceph) %dir %{_localstatedir}/lib/ceph/bootstrap-rgw
%attr(750,ceph,ceph) %dir %{_localstatedir}/lib/ceph/bootstrap-mgr
%attr(750,ceph,ceph) %dir %{_localstatedir}/lib/ceph/bootstrap-rbd

%post base
/sbin/ldconfig
%if 0%{?suse_version}
%fillup_only
if [ $1 -eq 1 ] ; then
/usr/bin/systemctl preset ceph-disk@\*.service ceph.target >/dev/null 2>&1 || :
fi
%endif
%if 0%{?fedora} || 0%{?rhel}
%systemd_post ceph-disk@\*.service ceph.target
%endif
if [ $1 -eq 1 ] ; then
/usr/bin/systemctl start ceph.target >/dev/null 2>&1 || :
fi

%preun base
%if 0%{?suse_version}
%service_del_preun ceph-disk@\*.service ceph.target
%endif
%if 0%{?fedora} || 0%{?rhel}
%systemd_preun ceph-disk@\*.service ceph.target
%endif

%postun base
/sbin/ldconfig
test -n "$FIRST_ARG" || FIRST_ARG=$1
%if 0%{?suse_version}
DISABLE_RESTART_ON_UPDATE="yes"
%service_del_postun ceph-disk@\*.service ceph.target
%endif
%if 0%{?fedora} || 0%{?rhel}
%systemd_postun ceph-disk@\*.service ceph.target
%endif
if [ $FIRST_ARG -ge 1 ] ; then
  # Restart on upgrade, but only if "CEPH_AUTO_RESTART_ON_UPGRADE" is set to
  # "yes". In any case: if units are not running, do not touch them.
  SYSCONF_CEPH=%{_sysconfdir}/sysconfig/ceph
  if [ -f $SYSCONF_CEPH -a -r $SYSCONF_CEPH ] ; then
    source $SYSCONF_CEPH
  fi
  if [ "X$CEPH_AUTO_RESTART_ON_UPGRADE" = "Xyes" ] ; then
    /usr/bin/systemctl try-restart ceph-disk@\*.service > /dev/null 2>&1 || :
  fi
fi

%files common
%dir %{_docdir}/ceph
%doc %{_docdir}/ceph/sample.ceph.conf
%doc %{_docdir}/ceph/COPYING
%{_bindir}/ceph
%{_bindir}/ceph-authtool
%{_bindir}/ceph-conf
%{_bindir}/ceph-rbdnamer
%{_bindir}/ceph-syn
%{_bindir}/ceph-crush-location
%{_bindir}/rados
%{_bindir}/radosgw-admin
%{_bindir}/rbd
%{_bindir}/rbd-replay
%{_bindir}/rbd-replay-many
%{_bindir}/rbdmap
%{_sbindir}/mount.ceph
%if 0%{?suse_version}
/sbin/mount.ceph
%endif
%if %{with lttng}
%{_bindir}/rbd-replay-prep
%endif
%exclude %{_bindir}/ceph-post-file
%exclude %{_bindir}/ceph-brag
%{_tmpfilesdir}/ceph-common.conf
%{_mandir}/man8/ceph-authtool.8*
%{_mandir}/man8/ceph-conf.8*
%{_mandir}/man8/ceph-dencoder.8*
%{_mandir}/man8/ceph-rbdnamer.8*
%{_mandir}/man8/ceph-syn.8*
%{_mandir}/man8/ceph-post-file.8*
%{_mandir}/man8/ceph.8*
%{_mandir}/man8/mount.ceph.8*
%{_mandir}/man8/rados.8*
%{_mandir}/man8/radosgw-admin.8*
%{_mandir}/man8/rbd.8*
%{_mandir}/man8/rbdmap.8*
%{_mandir}/man8/rbd-replay.8*
%{_mandir}/man8/rbd-replay-many.8*
%{_mandir}/man8/rbd-replay-prep.8*
%dir %{_datadir}/ceph/
%{_datadir}/ceph/known_hosts_drop.ceph.com
%{_datadir}/ceph/id_rsa_drop.ceph.com
%{_datadir}/ceph/id_rsa_drop.ceph.com.pub
%dir %{_sysconfdir}/ceph/
%config %{_sysconfdir}/bash_completion.d/ceph
%config %{_sysconfdir}/bash_completion.d/rados
%config %{_sysconfdir}/bash_completion.d/rbd
%config %{_sysconfdir}/bash_completion.d/radosgw-admin
%config(noreplace) %{_sysconfdir}/ceph/rbdmap
%{_unitdir}/rbdmap.service
%{python_sitelib}/ceph_argparse.py*
%{python_sitelib}/ceph_daemon.py*
%dir %{_udevrulesdir}
%{_udevrulesdir}/50-rbd.rules
%attr(3770,ceph,ceph) %dir %{_localstatedir}/log/ceph/
%attr(750,ceph,ceph) %dir %{_localstatedir}/lib/ceph/

%pre common
CEPH_GROUP_ID=167
CEPH_USER_ID=167
%if 0%{?rhel} || 0%{?fedora}
/usr/sbin/groupadd ceph -g $CEPH_GROUP_ID -o -r 2>/dev/null || :
/usr/sbin/useradd ceph -u $CEPH_USER_ID -o -r -g ceph -s /sbin/nologin -c "Ceph daemons" -d %{_localstatedir}/lib/ceph 2>/dev/null || :
%endif
%if 0%{?suse_version}
if ! getent group ceph >/dev/null ; then
    CEPH_GROUP_ID_OPTION=""
    getent group $CEPH_GROUP_ID >/dev/null || CEPH_GROUP_ID_OPTION="-g $CEPH_GROUP_ID"
    groupadd ceph $CEPH_GROUP_ID_OPTION -r 2>/dev/null || :
fi
if ! getent passwd ceph >/dev/null ; then
    CEPH_USER_ID_OPTION=""
    getent passwd $CEPH_USER_ID >/dev/null || CEPH_USER_ID_OPTION="-u $CEPH_USER_ID"
    useradd ceph $CEPH_USER_ID_OPTION -r -g ceph -s /sbin/nologin 2>/dev/null || :
fi
usermod -c "Ceph storage service" \
        -d %{_localstatedir}/lib/ceph \
        -g ceph \
        -s /sbin/nologin \
        ceph
%endif
exit 0

%post common
%tmpfiles_create %{_tmpfilesdir}/ceph-common.conf

%postun common
# Package removal cleanup
if [ "$1" -eq "0" ] ; then
    rm -rf %{_localstatedir}/log/ceph
    rm -rf %{_sysconfdir}/ceph
fi

%files mds
%{_bindir}/ceph-mds
%{_mandir}/man8/ceph-mds.8*
%{_unitdir}/ceph-mds@.service
%{_unitdir}/ceph-mds.target
%attr(750,ceph,ceph) %dir %{_localstatedir}/lib/ceph/mds

%post mds
%if 0%{?suse_version}
if [ $1 -eq 1 ] ; then
  /usr/bin/systemctl preset ceph-mds@\*.service ceph-mds.target >/dev/null 2>&1 || :
fi
%endif
%if 0%{?fedora} || 0%{?rhel}
%systemd_post ceph-mds@\*.service ceph-mds.target
%endif
if [ $1 -eq 1 ] ; then
/usr/bin/systemctl start ceph-mds.target >/dev/null 2>&1 || :
fi

%preun mds
%if 0%{?suse_version}
%service_del_preun ceph-mds@\*.service ceph-mds.target
%endif
%if 0%{?fedora} || 0%{?rhel}
%systemd_preun ceph-mds@\*.service ceph-mds.target
%endif

%postun mds
test -n "$FIRST_ARG" || FIRST_ARG=$1
%if 0%{?suse_version}
DISABLE_RESTART_ON_UPDATE="yes"
%service_del_postun ceph-mds@\*.service ceph-mds.target
%endif
%if 0%{?fedora} || 0%{?rhel}
%systemd_postun ceph-mds@\*.service ceph-mds.target
%endif
if [ $FIRST_ARG -ge 1 ] ; then
  # Restart on upgrade, but only if "CEPH_AUTO_RESTART_ON_UPGRADE" is set to
  # "yes". In any case: if units are not running, do not touch them.
  SYSCONF_CEPH=%{_sysconfdir}/sysconfig/ceph
  if [ -f $SYSCONF_CEPH -a -r $SYSCONF_CEPH ] ; then
    source $SYSCONF_CEPH
  fi
  if [ "X$CEPH_AUTO_RESTART_ON_UPGRADE" = "Xyes" ] ; then
    /usr/bin/systemctl try-restart ceph-mds@\*.service > /dev/null 2>&1 || :
  fi
fi

%files mgr
%{_bindir}/ceph-mgr
%{_libdir}/ceph/mgr
%{_unitdir}/ceph-mgr@.service
%{_unitdir}/ceph-mgr.target
%attr(750,ceph,ceph) %dir %{_localstatedir}/lib/ceph/mgr

%post mgr
%if 0%{?suse_version}
if [ $1 -eq 1 ] ; then
  /usr/bin/systemctl preset ceph-mgr@\*.service ceph-mgr.target >/dev/null 2>&1 || :
fi
%endif
%if 0%{?fedora} || 0%{?rhel}
%systemd_post ceph-mgr@\*.service ceph-mgr.target
%endif
if [ $1 -eq 1 ] ; then
/usr/bin/systemctl start ceph-mgr.target >/dev/null 2>&1 || :
fi

%preun mgr
%if 0%{?suse_version}
%service_del_preun ceph-mgr@\*.service ceph-mgr.target
%endif
%if 0%{?fedora} || 0%{?rhel}
%systemd_preun ceph-mgr@\*.service ceph-mgr.target
%endif

%postun mgr
test -n "$FIRST_ARG" || FIRST_ARG=$1
%if 0%{?suse_version}
DISABLE_RESTART_ON_UPDATE="yes"
%service_del_postun ceph-mgr@\*.service ceph-mgr.target
%endif
%if 0%{?fedora} || 0%{?rhel}
%systemd_postun ceph-mgr@\*.service ceph-mgr.target
%endif
if [ $FIRST_ARG -ge 1 ] ; then
  # Restart on upgrade, but only if "CEPH_AUTO_RESTART_ON_UPGRADE" is set to
  # "yes". In any case: if units are not running, do not touch them.
  SYSCONF_CEPH=%{_sysconfdir}/sysconfig/ceph
  if [ -f $SYSCONF_CEPH -a -r $SYSCONF_CEPH ] ; then
    source $SYSCONF_CEPH
  fi
  if [ "X$CEPH_AUTO_RESTART_ON_UPGRADE" = "Xyes" ] ; then
    /usr/bin/systemctl try-restart ceph-mgr@\*.service > /dev/null 2>&1 || :
  fi
fi

%files mon
%{_bindir}/ceph-mon
%{_bindir}/ceph-rest-api
%{_bindir}/ceph-monstore-tool
%{_mandir}/man8/ceph-mon.8*
%{_mandir}/man8/ceph-rest-api.8*
%{python_sitelib}/ceph_rest_api.py*
%{_unitdir}/ceph-mon@.service
%{_unitdir}/ceph-mon.target
%attr(750,ceph,ceph) %dir %{_localstatedir}/lib/ceph/mon

%post mon
%if 0%{?suse_version}
if [ $1 -eq 1 ] ; then
  /usr/bin/systemctl preset ceph-mon@\*.service ceph-mon.target >/dev/null 2>&1 || :
fi
%endif
%if 0%{?fedora} || 0%{?rhel}
%systemd_post ceph-mon@\*.service ceph-mon.target
%endif
if [ $1 -eq 1 ] ; then
/usr/bin/systemctl start ceph-mon.target >/dev/null 2>&1 || :
fi

%preun mon
%if 0%{?suse_version}
%service_del_preun ceph-mon@\*.service ceph-mon.target
%endif
%if 0%{?fedora} || 0%{?rhel}
%systemd_preun ceph-mon@\*.service ceph-mon.target
%endif

%postun mon
test -n "$FIRST_ARG" || FIRST_ARG=$1
%if 0%{?suse_version}
DISABLE_RESTART_ON_UPDATE="yes"
%service_del_postun ceph-mon@\*.service ceph-mon.target
%endif
%if 0%{?fedora} || 0%{?rhel}
%systemd_postun ceph-mon@\*.service ceph-mon.target
%endif
if [ $FIRST_ARG -ge 1 ] ; then
  # Restart on upgrade, but only if "CEPH_AUTO_RESTART_ON_UPGRADE" is set to
  # "yes". In any case: if units are not running, do not touch them.
  SYSCONF_CEPH=%{_sysconfdir}/sysconfig/ceph
  if [ -f $SYSCONF_CEPH -a -r $SYSCONF_CEPH ] ; then
    source $SYSCONF_CEPH
  fi
  if [ "X$CEPH_AUTO_RESTART_ON_UPGRADE" = "Xyes" ] ; then
    /usr/bin/systemctl try-restart ceph-mon@\*.service > /dev/null 2>&1 || :
  fi
fi

%files fuse
%{_bindir}/ceph-fuse
%{_mandir}/man8/ceph-fuse.8*
%{_sbindir}/mount.fuse.ceph
%{_unitdir}/ceph-fuse@.service
%{_unitdir}/ceph-fuse.target

%files -n rbd-fuse
%{_bindir}/rbd-fuse
%{_mandir}/man8/rbd-fuse.8*

%files -n rbd-mirror
%{_bindir}/rbd-mirror
%{_mandir}/man8/rbd-mirror.8*
%{_unitdir}/ceph-rbd-mirror@.service
%{_unitdir}/ceph-rbd-mirror.target

%post -n rbd-mirror
%if 0%{?suse_version}
if [ $1 -eq 1 ] ; then
  /usr/bin/systemctl preset ceph-rbd-mirror@\*.service ceph-rbd-mirror.target >/dev/null 2>&1 || :
fi
%endif
%if 0%{?fedora} || 0%{?rhel}
%systemd_post ceph-rbd-mirror@\*.service ceph-rbd-mirror.target
%endif
if [ $1 -eq 1 ] ; then
/usr/bin/systemctl start ceph-rbd-mirror.target >/dev/null 2>&1 || :
fi

%preun -n rbd-mirror
%if 0%{?suse_version}
%service_del_preun ceph-rbd-mirror@\*.service ceph-rbd-mirror.target
%endif
%if 0%{?fedora} || 0%{?rhel}
%systemd_preun ceph-rbd-mirror@\*.service ceph-rbd-mirror.target
%endif

%postun -n rbd-mirror
test -n "$FIRST_ARG" || FIRST_ARG=$1
%if 0%{?suse_version}
DISABLE_RESTART_ON_UPDATE="yes"
%service_del_postun ceph-rbd-mirror@\*.service ceph-rbd-mirror.target
%endif
%if 0%{?fedora} || 0%{?rhel}
%systemd_postun ceph-rbd-mirror@\*.service ceph-rbd-mirror.target
%endif
if [ $FIRST_ARG -ge 1 ] ; then
  # Restart on upgrade, but only if "CEPH_AUTO_RESTART_ON_UPGRADE" is set to
  # "yes". In any case: if units are not running, do not touch them.
  SYSCONF_CEPH=%{_sysconfdir}/sysconfig/ceph
  if [ -f $SYSCONF_CEPH -a -r $SYSCONF_CEPH ] ; then
    source $SYSCONF_CEPH
  fi
  if [ "X$CEPH_AUTO_RESTART_ON_UPGRADE" = "Xyes" ] ; then
    /usr/bin/systemctl try-restart ceph-rbd-mirror@\*.service > /dev/null 2>&1 || :
  fi
fi

%files -n rbd-nbd
%{_bindir}/rbd-nbd
%{_mandir}/man8/rbd-nbd.8*

%files radosgw
%{_bindir}/radosgw
%{_bindir}/radosgw-token
%{_bindir}/radosgw-es
%{_bindir}/radosgw-object-expirer
%{_mandir}/man8/radosgw.8*
%dir %{_localstatedir}/lib/ceph/radosgw
%{_unitdir}/ceph-radosgw@.service
%{_unitdir}/ceph-radosgw.target

%post radosgw
%if 0%{?suse_version}
if [ $1 -eq 1 ] ; then
  /usr/bin/systemctl preset ceph-radosgw@\*.service ceph-radosgw.target >/dev/null 2>&1 || :
fi
%endif
%if 0%{?fedora} || 0%{?rhel}
%systemd_post ceph-radosgw@\*.service ceph-radosgw.target
%endif
if [ $1 -eq 1 ] ; then
/usr/bin/systemctl start ceph-radosgw.target >/dev/null 2>&1 || :
fi

%preun radosgw
%if 0%{?suse_version}
%service_del_preun ceph-radosgw@\*.service ceph-radosgw.target
%endif
%if 0%{?fedora} || 0%{?rhel}
%systemd_preun ceph-radosgw@\*.service ceph-radosgw.target
%endif

%postun radosgw
test -n "$FIRST_ARG" || FIRST_ARG=$1
%if 0%{?suse_version}
DISABLE_RESTART_ON_UPDATE="yes"
%service_del_postun ceph-radosgw@\*.service ceph-radosgw.target
%endif
%if 0%{?fedora} || 0%{?rhel}
%systemd_postun ceph-radosgw@\*.service ceph-radosgw.target
%endif
if [ $FIRST_ARG -ge 1 ] ; then
  # Restart on upgrade, but only if "CEPH_AUTO_RESTART_ON_UPGRADE" is set to
  # "yes". In any case: if units are not running, do not touch them.
  SYSCONF_CEPH=%{_sysconfdir}/sysconfig/ceph
  if [ -f $SYSCONF_CEPH -a -r $SYSCONF_CEPH ] ; then
    source $SYSCONF_CEPH
  fi
  if [ "X$CEPH_AUTO_RESTART_ON_UPGRADE" = "Xyes" ] ; then
    /usr/bin/systemctl try-restart ceph-radosgw@\*.service > /dev/null 2>&1 || :
  fi
fi

%files osd
%{_bindir}/ceph-clsinfo
%{_bindir}/ceph-bluestore-tool
%{_bindir}/ceph-objectstore-tool
%{_bindir}/ceph-osdomap-tool
%{_bindir}/ceph-osd
%{_libexecdir}/ceph/ceph-osd-prestart.sh
%{_sbindir}/ceph-volume
%{_sbindir}/ceph-volume-systemd
%dir %{_udevrulesdir}
%{_udevrulesdir}/60-ceph-by-parttypeuuid.rules
%{_udevrulesdir}/95-ceph-osd.rules
%{_mandir}/man8/ceph-clsinfo.8*
%{_mandir}/man8/ceph-osd.8*
%{_mandir}/man8/ceph-bluestore-tool.8*
%{_mandir}/man8/ceph-volume.8*
%{_mandir}/man8/ceph-volume-systemd.8*
%if 0%{?rhel} && ! 0%{?centos}
%attr(0755,-,-) %{_sysconfdir}/cron.hourly/subman
%endif
%{_unitdir}/ceph-osd@.service
%{_unitdir}/ceph-osd.target
%{_unitdir}/ceph-volume@.service
%attr(750,ceph,ceph) %dir %{_localstatedir}/lib/ceph/osd
%config(noreplace) %{_sysctldir}/90-ceph-osd.conf

%post osd
%if 0%{?suse_version}
if [ $1 -eq 1 ] ; then
  /usr/bin/systemctl preset ceph-osd@\*.service ceph-volume@\*.service ceph-osd.target >/dev/null 2>&1 || :
fi
%endif
%if 0%{?fedora} || 0%{?rhel}
%systemd_post ceph-osd@\*.service ceph-volume@\*.service ceph-osd.target
%endif
if [ $1 -eq 1 ] ; then
/usr/bin/systemctl start ceph-osd.target >/dev/null 2>&1 || :
fi
%if 0%{?sysctl_apply}
    %sysctl_apply 90-ceph-osd.conf
%else
    /usr/lib/systemd/systemd-sysctl %{_sysctldir}/90-ceph-osd.conf > /dev/null 2>&1 || :
%endif

%preun osd
%if 0%{?suse_version}
%service_del_preun ceph-osd@\*.service ceph-volume@\*.service ceph-osd.target
%endif
%if 0%{?fedora} || 0%{?rhel}
%systemd_preun ceph-osd@\*.service ceph-volume@\*.service ceph-osd.target
%endif

%postun osd
test -n "$FIRST_ARG" || FIRST_ARG=$1
%if 0%{?suse_version}
DISABLE_RESTART_ON_UPDATE="yes"
%service_del_postun ceph-osd@\*.service ceph-volume@\*.service ceph-osd.target
%endif
%if 0%{?fedora} || 0%{?rhel}
%systemd_postun ceph-osd@\*.service ceph-volume@\*.service ceph-osd.target
%endif
if [ $FIRST_ARG -ge 1 ] ; then
  # Restart on upgrade, but only if "CEPH_AUTO_RESTART_ON_UPGRADE" is set to
  # "yes". In any case: if units are not running, do not touch them.
  SYSCONF_CEPH=%{_sysconfdir}/sysconfig/ceph
  if [ -f $SYSCONF_CEPH -a -r $SYSCONF_CEPH ] ; then
    source $SYSCONF_CEPH
  fi
  if [ "X$CEPH_AUTO_RESTART_ON_UPGRADE" = "Xyes" ] ; then
    /usr/bin/systemctl try-restart ceph-osd@\*.service ceph-volume@\*.service > /dev/null 2>&1 || :
  fi
fi

%if %{with ocf}

%files resource-agents
%dir %{_prefix}/lib/ocf
%dir %{_prefix}/lib/ocf/resource.d
%dir %{_prefix}/lib/ocf/resource.d/ceph
%attr(0755,-,-) %{_prefix}/lib/ocf/resource.d/ceph/rbd

%endif

%files -n librados2
%{_libdir}/librados.so.*
%dir %{_libdir}/ceph
%{_libdir}/ceph/libceph-common.so*
%if %{with lttng}
%{_libdir}/librados_tp.so.*
%endif

%post -n librados2 -p /sbin/ldconfig

%postun -n librados2 -p /sbin/ldconfig

%files -n librados-devel
%dir %{_includedir}/rados
%{_includedir}/rados/librados.h
%{_includedir}/rados/librados.hpp
%{_includedir}/rados/buffer.h
%{_includedir}/rados/buffer_fwd.h
%{_includedir}/rados/inline_memory.h
%{_includedir}/rados/page.h
%{_includedir}/rados/crc32c.h
%{_includedir}/rados/rados_types.h
%{_includedir}/rados/rados_types.hpp
%{_includedir}/rados/memory.h
%{_libdir}/librados.so
%if %{with lttng}
%{_libdir}/librados_tp.so
%endif
%{_bindir}/librados-config
%{_mandir}/man8/librados-config.8*

%files -n python-rados
%{python_sitearch}/rados.so
%{python_sitearch}/rados-*.egg-info

%files -n python%{python3_pkgversion}-rados
%{python3_sitearch}/rados.cpython*.so
%{python3_sitearch}/rados-*.egg-info

%files -n libradosstriper1
%{_libdir}/libradosstriper.so.*

%post -n libradosstriper1 -p /sbin/ldconfig

%postun -n libradosstriper1 -p /sbin/ldconfig

%files -n libradosstriper-devel
%dir %{_includedir}/radosstriper
%{_includedir}/radosstriper/libradosstriper.h
%{_includedir}/radosstriper/libradosstriper.hpp
%{_libdir}/libradosstriper.so

%files -n librbd1
%{_libdir}/librbd.so.*
%if %{with lttng}
%{_libdir}/librbd_tp.so.*
%endif

%post -n librbd1 -p /sbin/ldconfig

%postun -n librbd1 -p /sbin/ldconfig

%files -n librbd-devel
%dir %{_includedir}/rbd
%{_includedir}/rbd/librbd.h
%{_includedir}/rbd/librbd.hpp
%{_includedir}/rbd/features.h
%{_libdir}/librbd.so
%if %{with lttng}
%{_libdir}/librbd_tp.so
%endif

%files -n librgw2
%{_libdir}/librgw.so.*

%post -n librgw2 -p /sbin/ldconfig

%postun -n librgw2 -p /sbin/ldconfig

%files -n librgw-devel
%dir %{_includedir}/rados
%{_includedir}/rados/librgw.h
%{_includedir}/rados/rgw_file.h
%{_libdir}/librgw.so

%files -n python-rgw
%{python_sitearch}/rgw.so
%{python_sitearch}/rgw-*.egg-info

%files -n python%{python3_pkgversion}-rgw
%{python3_sitearch}/rgw.cpython*.so
%{python3_sitearch}/rgw-*.egg-info

%files -n python-rbd
%{python_sitearch}/rbd.so
%{python_sitearch}/rbd-*.egg-info

%files -n python%{python3_pkgversion}-rbd
%{python3_sitearch}/rbd.cpython*.so
%{python3_sitearch}/rbd-*.egg-info

%files -n libcephfs2
%{_libdir}/libcephfs.so.*

%post -n libcephfs2 -p /sbin/ldconfig

%postun -n libcephfs2 -p /sbin/ldconfig

%files -n libcephfs-devel
%dir %{_includedir}/cephfs
%{_includedir}/cephfs/libcephfs.h
%{_includedir}/cephfs/ceph_statx.h
%{_libdir}/libcephfs.so

%files -n python-cephfs
%{python_sitearch}/cephfs.so
%{python_sitearch}/cephfs-*.egg-info
%{python_sitelib}/ceph_volume_client.py*

%files -n python%{python3_pkgversion}-cephfs
%{python3_sitearch}/cephfs.cpython*.so
%{python3_sitearch}/cephfs-*.egg-info
%{python3_sitelib}/ceph_volume_client.py
%{python3_sitelib}/__pycache__/ceph_volume_client.cpython*.py*

%files -n python%{python3_pkgversion}-ceph-argparse
%{python3_sitelib}/ceph_argparse.py
%{python3_sitelib}/__pycache__/ceph_argparse.cpython*.py*
%{python3_sitelib}/ceph_daemon.py
%{python3_sitelib}/__pycache__/ceph_daemon.cpython*.py*

%if 0%{with ceph_test_package}
%files -n ceph-test
%{_bindir}/ceph-client-debug
%{_bindir}/ceph_bench_log
%{_bindir}/ceph_kvstorebench
%{_bindir}/ceph_multi_stress_watch
%{_bindir}/ceph_erasure_code
%{_bindir}/ceph_erasure_code_benchmark
%{_bindir}/ceph_omapbench
%{_bindir}/ceph_objectstore_bench
%{_bindir}/ceph_perf_objectstore
%{_bindir}/ceph_perf_local
%{_bindir}/ceph_perf_msgr_client
%{_bindir}/ceph_perf_msgr_server
%{_bindir}/ceph_psim
%{_bindir}/ceph_radosacl
%{_bindir}/ceph_rgw_jsonparser
%{_bindir}/ceph_rgw_multiparser
%{_bindir}/ceph_scratchtool
%{_bindir}/ceph_scratchtoolpp
%{_bindir}/ceph_smalliobench
%{_bindir}/ceph_smalliobenchdumb
%{_bindir}/ceph_smalliobenchfs
%{_bindir}/ceph_smalliobenchrbd
%{_bindir}/ceph_test_*
%{_bindir}/ceph_tpbench
%{_bindir}/ceph_xattr_bench
%{_bindir}/ceph-coverage
%{_bindir}/ceph-debugpack
%{_mandir}/man8/ceph-debugpack.8*
%dir %{_libdir}/ceph
%{_libdir}/ceph/ceph-monstore-update-crush.sh
%endif

%if 0%{with cephfs_java}
%files -n libcephfs_jni1
%{_libdir}/libcephfs_jni.so.*

%post -n libcephfs_jni1 -p /sbin/ldconfig

%postun -n libcephfs_jni1 -p /sbin/ldconfig

%files -n libcephfs_jni-devel
%{_libdir}/libcephfs_jni.so

%files -n cephfs-java
%{_javadir}/libcephfs.jar
%{_javadir}/libcephfs-test.jar
%endif

%files -n rados-objclass-devel
%dir %{_includedir}/rados
%{_includedir}/rados/objclass.h

%if 0%{with selinux}
%files selinux
%attr(0600,root,root) %{_datadir}/selinux/packages/ceph.pp
%{_datadir}/selinux/devel/include/contrib/ceph.if
%{_mandir}/man8/ceph_selinux.8*

%post selinux
# backup file_contexts before update
. /etc/selinux/config
FILE_CONTEXT=/etc/selinux/${SELINUXTYPE}/contexts/files/file_contexts
cp ${FILE_CONTEXT} ${FILE_CONTEXT}.pre

# Install the policy
/usr/sbin/semodule -i %{_datadir}/selinux/packages/ceph.pp

# Load the policy if SELinux is enabled
if ! /usr/sbin/selinuxenabled; then
    # Do not relabel if selinux is not enabled
    exit 0
fi

if diff ${FILE_CONTEXT} ${FILE_CONTEXT}.pre > /dev/null 2>&1; then
   # Do not relabel if file contexts did not change
   exit 0
fi

# Check whether the daemons are running
/usr/bin/systemctl status ceph.target > /dev/null 2>&1
STATUS=$?

# Stop the daemons if they were running
if test $STATUS -eq 0; then
    /usr/bin/systemctl stop ceph.target > /dev/null 2>&1
fi

# Relabel the files
# Use ceph-disk fix for first package install and fixfiles otherwise
if [ "$1" = "1" ]; then
    /usr/sbin/ceph-disk fix --selinux
else
    /usr/sbin/fixfiles -C ${FILE_CONTEXT}.pre restore 2> /dev/null
fi

rm -f ${FILE_CONTEXT}.pre
# The fixfiles command won't fix label for /var/run/ceph
/usr/sbin/restorecon -R /var/run/ceph > /dev/null 2>&1

# Start the daemons iff they were running before
if test $STATUS -eq 0; then
    /usr/bin/systemctl start ceph.target > /dev/null 2>&1 || :
fi
exit 0

%postun selinux
if [ $1 -eq 0 ]; then
    # backup file_contexts before update
    . /etc/selinux/config
    FILE_CONTEXT=/etc/selinux/${SELINUXTYPE}/contexts/files/file_contexts
    cp ${FILE_CONTEXT} ${FILE_CONTEXT}.pre

    # Remove the module
    /usr/sbin/semodule -n -r ceph > /dev/null 2>&1

    # Reload the policy if SELinux is enabled
    if ! /usr/sbin/selinuxenabled ; then
        # Do not relabel if SELinux is not enabled
        exit 0
    fi

    # Check whether the daemons are running
    /usr/bin/systemctl status ceph.target > /dev/null 2>&1
    STATUS=$?

    # Stop the daemons if they were running
    if test $STATUS -eq 0; then
        /usr/bin/systemctl stop ceph.target > /dev/null 2>&1
    fi

    /usr/sbin/fixfiles -C ${FILE_CONTEXT}.pre restore 2> /dev/null
    rm -f ${FILE_CONTEXT}.pre
    # The fixfiles command won't fix label for /var/run/ceph
    /usr/sbin/restorecon -R /var/run/ceph > /dev/null 2>&1

    # Start the daemons if they were running before
    if test $STATUS -eq 0; then
	/usr/bin/systemctl start ceph.target > /dev/null 2>&1 || :
    fi
fi
exit 0

%endif # with selinux

%files -n python-ceph-compat
# We need an empty %%files list for python-ceph-compat, to tell rpmbuild to
# actually build this meta package.


%changelog
* Thu Apr 26 2018 ncutler@suse.com
- Update to version 12.2.5-407-g5e7ea8cf03:
  + osd: do not crash on empty snapset (bsc#1074301)
  + mon: add 'ceph osd pool get erasure allow_ec_overwrites' command
    (bsc#1087269)
* Wed Apr 25 2018 ncutler@suse.com
- Update to version 12.2.5-405-gb4dd2afd81
  + upstream v12.2.5 point release
  * journal: limit number of appends sent in one librados op
    (bsc#1086340)
  * RGW user stats fixes (bsc#1087493)
* Tue Mar  6 2018 ncutler@suse.com
- Update to version 12.2.4+git.1520347944.ea5f50680a:
  + rgw openssl fixes (bsc#1079076, bsc#1081379)
* Sat Mar  3 2018 ncutler@suse.com
- Update to version 12.2.4+git.1520094840.20594f896d:
  + merge upstream point releases v12.2.3 and v12.2.4
  * rocksdb: fixes early metadata spill over to slow device in bluefs
    (bsc#1071386)
  * mon: reenable timer to send digest when paxos is temporarily inactive
    (bsc#1070357)
  * fsid mismatch when creating additional OSDs (bsc#1080788)
  * rgw: malformed http headers can crash rgw (bsc#1081379, CVE-2018-7262)
  * crash in civetweb/RGW (bsc#1081600)
- migrate tarball generation from tar_scm source service to upstream make-dist
  script
  + drop _service, _servicedata
  + add checkin.sh, README-checkin.sh
* Wed Feb 21 2018 ncutler@suse.com
- Update to version 12.2.2+git.1519207306.ac2f91f62a:
  + qa
  * install deepsea from packages instead of source
  * add suse/smoke and deepsea/adhoc suites
  + rgw: make init env methods return an error (bsc#1081379, CVE-2018-7262)
* Fri Dec 15 2017 ncutler@suse.com
- Update to version 12.2.2+git.1513357992.5030136da9:
  + tools/crushtool: skip device id if no name exists (bsc#1067119)
  + pybind/mgr/prometheus: don't crash when encountering an unknown PG state
  + mgr/prometheus: add missing 'deep' state to PG_STATES in ceph-mgr prometheus plugin
* Wed Dec 13 2017 ncutler@suse.com
- Update to version 12.2.2+git.1513167344.b87ca3c12e:
  + upstream v12.2.2 release
    for details, see https://ceph.com/releases/v12-2-2-luminous-released/
* Fri Nov 24 2017 ncutler@suse.com
- Drop _link to reflect that filesystems:ceph:luminous/ceph is no
  longer the source for filesystems:ceph/luminous (the Factory/TW
  devel project). Development of ceph in Factory/TW will continue
  in filesystems:ceph:mimic/ceph.
* Tue Nov 21 2017 ncutler@suse.com
- Update to version 12.2.1+git.1511279898.8aa892202e:
  + bsc#1060904
  * rgw: keystone: bump up logging when error is received
  + bsc#1067705
  * rgw: set sync_from_all as true when no value is seen
  + bsc#1066182
  * rgw: data sync: set num_shards when building full maps
  * dencoder/rgw: expose rgw sync status types
  * rgw: set num_shards on 'radosgw-admin data sync init'
* Thu Nov  9 2017 ncutler@suse.com
- Update to version 12.2.1+git.1510221942.af9ea5e715:
  + bsc#1066502
  * mon/osd_metadata: sync osd_metadata table
  * mon/OSDMonitor: tidy prefix definitions
  * mon: implement MDSMonitor::get_store_prefixes
  * mon/mgr: sync mgr_command_descs table and mgr_metadata table
  * mon/MgrMonitor: populate on-disk cmd descs if empty on upgrade
  * mon/MgrMonitor: read cmd descs if empty on update_from_paxos()
  + bsc#1067088
  * osd: make the PG's SORTBITWISE assert a more generous shutdown
  + bsc#1066182
  * rgw: ListBucketIndexesCR spawns entries_index after listing metadata
  * rgw: fix error handling in ListBucketIndexesCR
  * rgw: RGWDataSyncControlCR retries on all errors
  + RGW fixes:
  * test/rgw: add test_multipart_object_sync
  * cls/rgw: increment header version to avoid overwriting bilog entries
  * rgw: disable dynamic resharding in multisite environment
* Fri Oct 27 2017 ncutler@suse.com
- Update to version 12.2.1+git.1509128342.9347aa6662:
  + common/common_init: disable ms subsystem log gathering for clients
  + spec file: add %%{_sysctldir}/90-ceph-osd.conf to ceph-osd
  * ceph.spec.in,debian/rules: change aio-max-nr to 1048576
  * sysctl.d: set kernel.pid_max=4194304 (bsc#1061461)
* Sun Oct 15 2017 ncutler@suse.com
- Update to version 12.2.1+git.1507910930.aea79b8b7a:
  + rgw: Remove assertions in IAM Policy (bsc#1063014, CVE-2017-16818)
* Thu Oct 12 2017 ncutler@suse.com
- Update to version 12.2.1+git.1507819941.856710ff58:
  + rgw: stop/join TokenCache revoke thread only if started (bsc#1059458)
  + systemd: reinstate TasksMax=infinity
* Thu Oct  5 2017 ncutler@suse.com
- Update to version 12.2.1+git.1507226092.b783a015b9:
  + Revert "SIGPIPE suppression for platforms without SO_NOSIGPIPE or MSG_NOSIGNAL"
  + msgr: add a mechanism for Solaris to avoid dying on SIGPIPE
* Wed Oct  4 2017 ncutler@suse.com
- Update to version 12.2.1+git.1507108986.dc637a73e2:
  + rgw: defer constructing keystone engine unless url is configured
    (issue#21400, pr#17775)
* Sat Sep 30 2017 ncutler@suse.com
- Update to version 12.2.1+git.1506764331.9e2e945bd0:
  (upstream luminous 9d8acf6f3f85dd1410629cc680474e38f3be9838)
  + upstream Luminous v12.2.1
    https://ceph.com/releases/v12-2-1-luminous-released/
* Thu Sep 21 2017 ncutler@suse.com
- Update to version 12.2.0+git.1506009682.0e5b4307f3
  (upstream luminous a931cf68120d99661b785cc794e2b6965d621f06):
  + ceph-disk: fix mountpoint check for systemctl enable --runtime
    (bsc#1051598)
  + spec file:
  * ceph-fuse requires fuse; make that dependency explicit
  * drop obsolete qemu symlink hack in librbd1 %%post
* Mon Sep 11 2017 ncutler@suse.com
- Update to version 12.2.0+git.1505141259.1264bae1a8:
  + rgw_file: fix LRU lane lock in evict_block() - bsc#1054061
  + os/bluestore: fix deferred write deadlock, aio short return handling -
    bsc#1056125
  + mon/OSDMonitor: don't create pgs if pool was deleted - bsc#1056967
* Wed Aug 30 2017 ncutler@suse.com
- Update to version 12.2.0+git.1504118058.706f78da1a:
  + fix ceph --version to say "stable" instead of "rc"
  + spec file: add python-numpy-devel build dependency for SUSE
  + bsc#1053836
  * Revert "osd: adjust osd_min_pg_log_entries"
  * osd/PGLog: write only changed dup entries
* Tue Aug 29 2017 ncutler@suse.com
- Update to version 12.2.0+git.1504013812.01ea30bcc9:
  + upstream Luminous v12.2.0 (first stable) release
  * increment version number to 12.2.0
  + spec file
  * edge mem_per_process upward after seeing some OOM-esque build failures
  * package ceph-volume man pages
* Thu Aug 17 2017 ncutler@suse.com
- Update to version 12.1.4+git.1502953626.155adb5253:
  + ceph.spec: provide libxio 1.7 and obsolete libxio <= 1.7
* Wed Aug 16 2017 ncutler@suse.com
- Update to version 12.1.4+git.1502878199.4183317204:
  + ceph.spec: obsolete libxio
    (Note to reviewer: libxio was only ever used by Ceph (for an experimental
    IB/RDMA feature), it was never submitted to Factory, and its functionality has
    been integrated into Ceph in a different form. For all practical purposes,
    libxio has been replaced by Ceph itself.)
* Wed Aug 16 2017 ncutler@suse.com
- Update to version 12.1.4+git.1502871088.edf82a59df:
  + latest upstream luminous (a5f84b37668fc8e03165aaf5cbb380c78e4deba4)
  * increment upstream version number to 12.1.4
* Mon Aug 14 2017 ncutler@suse.com
- Update to version 12.1.3+git.1502698163.45fc586a51:
  + latest upstream luminous (6808af486d3bdce966232810004648502c967b13)
  * increment upstream version number to 12.1.3
* Sat Aug  5 2017 ncutler@suse.com
- Update to version 12.1.2+git.1501914637.59afe41c49:
  + spec file
  * ceph-volume added to ceph-base RPM, where it co-exists with ceph-disk
* Fri Aug  4 2017 ncutler@suse.com
- Update to version 12.1.2+git.1501865907.88dc8cdc9d:
  + latest upstream master (7350fa65d79b5f0ace427e609565f07be35cfe62)
  * os/bluestore: allow multiple DeferredBatches in flight at once
    (pr#16769, issue#20295, bsc#1043399)
* Thu Aug  3 2017 ncutler@suse.com
- Update to version 12.1.2+git.1501790037.82d6a9c37a:
  + osd: move CMPEXT response munging into completion function
    (bsc#1047244)
* Wed Aug  2 2017 ncutler@suse.com
- Update to version 12.1.2+git.1501684697.aa6b0153ef:
  + upstream luminous v12.1.2 release candidate
  + latest upstream master (e27a78c9ed3984b54a312ced3ad67fcc8f464fc0)
  * mon: add mgr metdata commands, and overall 'versions' command for all
    daemon versions (bsc#1050063, pr#16460)
* Wed Aug  2 2017 ncutler@suse.com
- Update to version 12.1.1+git.1501669490.04d0738487:
  + mon: extensible output format for health checks
* Mon Jul 31 2017 ncutler@suse.com
- Update to version 12.1.1+git.1501501507.6dd9e8fd8c:
  + update to latest upstream master (fa70335db25f2b661b329d5d8f37039b77f2d1ae)
  + spec file:
  * build/ops: rpm: Drop legacy libxio support (pr#16449)
  + Other notable changes:
  * osd: moved OpFinisher logic from OSDOp to OpContext (pr#16617)
* Fri Jul 28 2017 tserong@suse.com
- Update to version 12.1.1+git.1501231943.67577225bc
  + Notable changes:
  * rgw_file: properly & |'d flags (bsc#1047977)
* Wed Jul 19 2017 ncutler@suse.com
- Update to version 12.1.1+git.1500447879.e5aac115d7:
  + upstream 12.1.1 (release candidate)
  + Other notable changes:
  * build/ops: rpm: fix typo WTIH_BABELTRACE (pr#16366)
  * build/ops: rpm: put mgr python build dependencies in make_check bcond
    (pr#15940)
  * ceph-disk: support osd new (pr#15432)
  * ceph: allow '-' with -i and -o for stdin/stdout (pr#16359)
  * cls/rbd: trash_list should be iterable (pr#16372)
  * doc: update quick start to add a note for mgr create command for luminous+
    builds (pr#16350)
  * libradosstriper: fix format injection vulnerability (pr#15674)
  * mgr/dashboard: add OSD list view (pr#16373)
  * mon, osd: misc fixes (pr#16283)
  * mon/MDSMonitor: fix segv when multiple MDSs raise same alert (pr#16302)
  * mon/MgrMonitor: fix standby addition to mgrmap (pr#16397)
  * mon/MgrMonitor: only induce mgr epoch shortly after mkfs (pr#16356)
  * mon: Fix output text and doc (pr#16367)
  * mon: add force-create-pg back (pr#16353)
  * mon: skip crush smoke test when running under valgrind (pr#16346)
  * os/bluestore: use reference to avoid string copy (pr#16364)
  * osd: combine conditional statements (pr#16391)
  * osd: restart boot process if waiting for luminous mons (pr#16341)
  * rgw: S3 lifecycle now supports expiration date (pr#15807)
  * rgw: acl grants num limit (pr#16291)
  * rgw: delete object in error path (pr#16324)
  * rgw: drop unused find_replacement() and some function docs (pr#16386)
  * rgw: fix err when copy object in bucket with specified placement rule
    (pr#15837)
  * rgw: fix potential null pointer dereference in rgw_admin (pr#15667)
  * rgw: raise debug level of RGWPostObj_ObjStore_S3::get_policy (pr#16203)
  * rgw: req xml params size limitation error msg (pr#16310)
  * rgw_file:  add service map registration (pr#16251)
  * test,rgw: fix rgw placement rule pool config option (pr#16380)
  * test/fio: print all perfcounters rather than objectstore itself (pr#16339)
* Mon Jul 17 2017 ncutler@suse.com
- Update to version 12.1.0+git.1500295948.39d2e5f424:
  + spec file:
  * socat build dependency only for make check
  * fix typo WTIH_BABELTRACE
* Mon Jul 17 2017 ncutler@suse.com
- Update to version 12.1.0+git.1500284183.1ed97736ab:
  + Spec file changes:
  * bump epoch (not relevant for SUSE)
  * add socat buildrequires
  * libcephfs2 now obsoletes libcephfs1 (bsc#1047020)
  * HAVE_BABELTRACE option renamed to WITH_BABELTRACE
  * fix a regression in ceph-base %%postun scriptlet
  + Selected other changes:
  * Revert "msg/async: increase worker reference with local listen table enabled backend"
  * build: build erasure-code isa lib without versions
  * ceph-disk/ceph_disk/main.py: Replace ST_ISBLK() test by is_diskdevice()
  * ceph.in: filter out audit from ceph -w
  * common,config: OPT_FLOAT and OPT_DOUBLE output format in config show
  * common/Timer: do not add event if already shutdown
  * compressor/zlib: remove g_ceph_context/g_conf from compressor plugin
  * core: make the conversion from wire error to host OS work
  * core:" Stringify needs access to << before reference" src/include/stringify.h
  * crush/CrushWrapper: make get_immediate_parent[_id] ignore per-class shadow hierarchy
  * doc/mgr/dashboard: update dashboard docs to reflect new defaults
  * doc/rados.8: add offset option for put command
  * doc: fix link for ceph-mgr cephx authorization
  * doc: update intro, quick start docs
  * isa-l: update isa-l to v2.18
  * librbd: fail IO request when exclusive lock cannot be obtained
  * mgr,librados: service map
  * mgr,mon: debug init and mgrdigest subscriptions
  * mgr,mon: enable/disable mgr modules via 'ceph mgr module ...' commands
  * mgr/ClusterState: do not mangle PGMap outside of Incremental
  * mgr/restful: bind to :: and update docs
  * mgr: Zabbix monitoring module
  * mon,crush: create crush rules using device classes for replicated and ec pools via cli
  * mon/MgrStatMonitor: do not crash on luminous dev version upgrades
  * mon/MonClient: respect the priority in SRV RR
  * mon/Monitor: recreate mon session if features changed
  * mon/OSDMonitor: do not allow crush device classes until luminous
  * mon/OSDMonitor: guard 'osd crush set-device-class'
  * mon/mgr: add detail error infomation
  * mon: Fix status output warning for mon_warn_osd_usage_min_max_delta
  * mon: add support public_bind_addr option
  * mon: collect mon metdata as part of the election
  * mon: debug session feature tracking
  * mon: do crushtool test with fork and timeout, but w/o exec of crushtool
  * mon: fix hang on deprecated/removed 'pg set_\*full_ratio' commands
  * mon: include device class in tree view; hide shadow hierarchy
  * mon: maintain the "cluster" PerfCounters when using ceph-mgr
  * mon: revamp health check/warning system
  * msg/async: increase worker reference with local listen table enabled backend
  * msg/async: make recv_stamp more precise
  * msg: QueueStrategy::wait() joins all threads
  * msg: make listen backlog an option, increase from 128 to 512
  * os/blueStore: Failure retry for opening file
  * os/bluestore/BlueFS: clean up log_writer aios from compaction
  * os/bluestore/BlueFS: clear current log entrys before dump all fnode
  * os/bluestore/KernelDevice: batch aio submit
  * os/bluestore: Make BitmapFreelistManager kv itereator short lived
  * os/bluestore: cap rocksdb cache size
  * os/bluestore: clear up redundant size assignment in KernelDevice
  * os/bluestore: differ default cache size for hdd/ssd backends
  * os/bluestore: fix deferred_aio deadlock
  * os/bluestore: move object exist in assign nid
  * os/bluestore: only submit deferred if there is any
  * os/bluestore: reduce some overhead for _do_clone_range() and _do_remove()
  * os/bluestore: use bufferlist functions whenever possible
  * os/filestore/FileJournal: FileJournal::open() close journal file before return error
  * os/filestore/HashIndex: randomize split threshold by a configurable amount
  * os/filestore: call committed_thru when no journal entries are replayed
  * os/filestore: do not free event if not added
  * os/filestore: queue ondisk completion before apply work
  * os/filestore: require experimental flag for btrfs
  * osd/OSD: auto class on osd start up
  * osd/PrimaryLogPG solve cache tier osd high memory consumption
  * osd/ReplicatedBackend: reset thread heartbeat after every omap entry
  * osd/filestore: Revert "os/filestore: move ondisk in front
  * osd: Check for and automatically repair object info soid during scrub
  * osd: Preserve OSDOp information for historic ops
  * osd: check queue_transaction return value
  * osd: clear_queued_recovery() in on_shutdown()
  * osd: compact osd feature
  * pybind/mgr/dashboard: bind to :: by default
  * pybind/mgr/dashboard: fix get kernel_version error
  * rbd-mirror: ignore permission errors on rbd_mirroring object
  * rbd: do not attempt to load key if auth is disabled
  * rgw: fix compilation with cryptopp
  * rgw,test: fix rgw placement rule pool config option
  * rgw/rgw_frontend.h: Return negative value for empty uid in RGWLoadGenFrontend::init()
  * rgw/rgw_rados: Remove duplicate calls in RGWRados::finalize()
  * rgw: /info claims we do support Swift's accounts ACLs
  * rgw: Correcting the condition in ceph_assert while parsing an AWS Principal
  * rgw: Do not fetch bucket stats by default upon bucket listing
  * rgw: Fix a bug that multipart upload may exceed the quota
  * rgw: Initialize pointer fields
  * rgw: fix leaks with incomplete multiparts
  * rgw: fix memory leak in copy_obj_to_remote_dest
  * rgw: fix not initialized vars which cause rgw crash with ec data pool
  * rgw: fix radosgw-admin data sync run crash
  * rgw: fix s3 object uploads with chunked transfers and v4 signatures
  * rgw: fix the subdir without slash of s3 website url
  * rgw: fix zone did't update realm_id when added to zonegroup
  * rgw: log_meta only for more than one zone
  * rgw: rgw_file skip policy read for virtual components
  * rgw: using RGW_OBJ_NS_MULTIPART in check_bad_index_multipart
  * rgw: verify md5 in post obj
  * rgw_file: add compression interop to RGW NFS
  * rgw：fix s3 aws v2 signature priority between header['X-Amz-Date'] and header['Date']
  * vstart.sh: bind restful, dashboard to ::, not 127.0.0.1
  * vstart: add --rgw_compression to set rgw compression plugin
  * vstart: allow to start multiple radosgw when RGW=x
* Mon Jul  3 2017 ncutler@suse.com
- Update to version 12.1.0+git.1499090920.2c11b88d14:
  + With this update, Ceph no longer autocreates a pool called "rbd" with id 0
    Deployment tools must take this into account!
  + systemd: Add explicit Before=ceph.target (bsc#1042973)
* Wed Jun 28 2017 ncutler@suse.com
- Update to version 12.1.0+git.1498654198.20d6a47cc9:
  + build/ops: rpm: put mgr python build dependencies in make_check bcond
    N.B. this effectively eliminates the following build dependencies:
    python-Babel python-beautifulsoup4 python-CherryPy python-coverage
    python-flup python-Genshi python-html5lib python-logutils python-nose
    python-Paste python-PasteDeploy python-PasteDeploy python-pecan
    python-pyquery python-singledispatch python-waitress python-WebOb
    python-WebTest python-Werkzeug python-WSGIProxy2 pytyhon-python-openid
* Mon Jun 26 2017 ncutler@suse.com
- spec file:
  + removed BR libatomic_ops-devel as upstream replaced it with std:atomic
  + removed defattr as they are no longer needed on sle12 and newer
* Mon Jun 26 2017 ncutler@suse.com
- Update to version 12.1.0+git.1498478524.117b171715:
  + include 12.1.0 tag to make "ceph --version" happy
  + tests: drop hadoop-s3a tests
* Sat Jun 24 2017 ncutler@suse.com
- Update to version 12.1.0+git.1498309403.f4fc02fff4:
  + upstream 12.1.0 release; for details, see
    http://ceph.com/releases/v12-1-0-luminous-rc-released/
  + revert several pre-release commits that are no longer needed
    because the issues have been fixed upstream in the meantime
  + build/ops: rpm: sane packaging of %%{_docdir}/ceph directory
* Fri Jun 23 2017 ncutler@suse.com
- Update to version 12.0.3+git.1498202776.b806032985:
  + Integration testing changes:
  * add DeepSea integration suite test definitions for teuthology
  * re-enable several RGW tests that upstream only runs on Ubuntu
  + ceph_ver_hack.sh: use git describe --match
  + ReplicatedPG: add CHECKSUM->CMPEXT req translation
* Wed Jun 14 2017 ncutler@suse.com
- Update to version 12.0.3+git.1497426468.6984d41b5d:
  + qa: add initial deepsea suite (task and test yaml)
  + fix "ceph osd df" (regression in latest upstream master) (pr#15675, issue#20256)
  * mon: move creating_pgs and reweight_by_utilization into new MonPGStatService
  * mon: move most PGMapStatService into PGMap; rename PGMon's to PGMonStatService
  * mon: mgr: move 'osd df' handling to manager
  * mon: inherit PGMonStatService from the PGMapStatService
  * move the OSDUtilizationDumper code into OSDMap
  * mon: mgr: enable "osd df" on the manager
  * qa: add a check_commands.sh script which looks for commands with no tests
  * qa: test 'osd df' in cephtool/test.sh
* Thu Jun  8 2017 ncutler@suse.com
- Update to version 12.0.3+git.1496909744.9f667dc335:
  + build/ops: rpm: one License line to rule them all
* Thu Jun  8 2017 ncutler@suse.com
- up memory _constraint for ceph-test to address ppc64le OOM seen in IBS
* Thu Jun  8 2017 ncutler@suse.com
- Update to version 12.0.3+git.1496902753.b18dc53186:
  + build/ops: rpm, COPYING: drop GPL 2.0 with Autoconf Exception
    (autoconf no longer used)
* Wed Jun  7 2017 ncutler@suse.com
- Update to version 12.0.3+git.1496754880.35cb2861ce:
  + merge upstream master (b1d06a6b54)
* Sat Jun  3 2017 ncutler@suse.com
- Update to version 12.0.3+git.1496494491.ba3c561a92:
  + merge upstream master (97d6e150e5)
* Thu Jun  1 2017 ncutler@suse.com
- Update to version 12.0.3+git.1496306960.2db336d85e:
  + merge upstream master (b19352eec3), fixes bsc#1041492
* Tue May 30 2017 ncutler@suse.com
- Update to version 12.0.3+git.1496147556.f1d6115861:
  + cmake: build boost::context and coroutine only with rgw Beast frontend
  + build/ops: rpm: reverse s390 bcond conditional block
  + build/ops: rpm: no rgw Beast frontend on s390x
  + build/ops: deb: no rgw Beast frontend on s390x
  + cmake: delete excidentail reintroduced line.
  + cmake: link radosgw with boost libraries
  (bsc#1040119)
* Sat May 27 2017 ncutler@suse.com
- Update to version 12.0.3+git.1495849076.4457d36178:
  + rgw: remove fastcgi from default rgw frontends
  + RGW: Turn off fcgi as a frontend
  + build/ops: drop libfcgi build dependency
  + build/ops: rpm: apply epoch only if %%epoch macro is defined
* Fri May 26 2017 ncutler@suse.com
- Update to version 12.0.3+git.1495798013.23dd2b67dc:
  + ceph.spec.in: re-drop %%{epoch}: prefixes
* Fri May 26 2017 ncutler@suse.com
- Update to version 12.0.3+git.1495787939.3f6446f64f:
  + build/ops: rpm: adapt License line to Release 2.0 of SPDX spec
    (issue#20091)
* Fri May 26 2017 ncutler@suse.com
- Update to version 12.0.3+git.1495675338.07282a4057:
  + upstream 12.0.3 release
  + osd/PG: Add two new mClock implementations of the PG sharded operator queue
    (pr#14997, bsc#1040103)
  + build/ops: rpm: make librbd1 %%post scriptlet depend on coreutils (boo#1040230)
  + build/ops: rpm: move RDMA build dependency to distro-conditional section
  + build/ops: rpm: move python-prettytable to distro-conditional section
  + cmake: added empty RPATH to libcls_sdk.so
  + rpm: drop %%{epoch} from new rados-objclass-devel subpackage
  + cmake: fix boost components for WITH_SYSTEM_BOOST
  + cmake: build boost::context only if rgw Beast frontend is in use
  + build/ops: rpm: reverse s390 bcond conditional block
  + build/ops: rpm: no rgw Beast frontend on s390x (bsc#1040119)
  + ceph.spec.in, debian/control: build/runtime dependency for cherrypy
* Wed May 10 2017 ncutler@suse.com
- Update to version 12.0.2+git.1494343993.7527e4f0b8:
  + ReplicatedPG: drop CACHE_PIN->WRITESAME req translation (bsc#1038063)
* Tue May  9 2017 ncutler@suse.com
- _constraints: up ceph.spec disk constraint to 28G after seeing a
  build failure in OBS
* Fri Apr 28 2017 ddiss@suse.com
- Update to version 12.0.2+git.1493341348.9148e53:
  + ceph osd: add support for new op cmpext
  + ceph_test_rados_api_misc: add cmpext tests
  + librados: add cmpext API
  + ceph_test_rados_api_aio: add cmpext tests
  + test/librados/c_operations: add cmpext tests
  This patchset is a straight cherry-pick of the upstream OSD/librados cmpext
  changes (bsc#1035937).
* Thu Apr 27 2017 ncutler@suse.com
- Update to version 12.0.2+git.1493291471.adb6a43:
  + rocksdb: sync with upstream (bsc#1025891)
  + build/ops: cmake: explicitly disable MSSE 4.2 if not supported
* Thu Apr 27 2017 ncutler@suse.com
- _constraints: set higher disk and memory constraints so s390x
  builds don't fail
* Wed Apr 26 2017 ncutler@suse.com
- Update to version 12.0.2+git.1493238434.71681fd:
  + cmake: added empty RPATH to libceph_crypto_isal.so
* Wed Apr 26 2017 ncutler@suse.com
- Update to version 12.0.2+git.1493227670.3396ca1:
  + rgw: use a vector for options passed to civetweb
* Wed Apr 26 2017 ncutler@suse.com
- Update to version 12.0.2+git.1493192333.3305a0c
  + merge upstream master (0d368d2c8544247a4aed9c71c74e77b0c6bbfb22)
    including 12.0.2 development release
* Tue Apr 25 2017 ddiss@suse.com
- revert commit a9a50f690085091bb4446095418237f9fef712c8 in preparation for
  rebasing against the upstream implementation.  (bsc#1035937)
* Fri Apr  7 2017 ncutler@suse.com
- Add ibs_constraints.sh script to address s390 constraints
  tweak needed in IBS
* Fri Apr  7 2017 ncutler@suse.com
- Update to version 12.0.1+git.1491557762.4e47e9f
  + merge upstream master (2950ad91d25d0d6e2e3fb6842d5bbc36353ba2a5)
    including fixes for:
  * bsc#1030068 (s390 build)
  * bsc#1031311 (ceph-mon.service not enabled via systemd preset)
* Tue Apr  4 2017 ncutler@suse.com
- Mention bugs fixed in jewel codestream that are also fixed in the current
  codestream:
  + msg/simple/Pipe: avoid returning 0 on poll timeout (bsc#1014338)
  + build/ops: fix undefined crypto references with --with-xio (bsc#977940)
  + ceph-create-keys: add missing argument comma (bsc#1008894)
  + common: Improve linux dcache hash algorithm (bsc#1005179)
* Tue Mar 14 2017 ncutler@suse.com
- Update to version 12.0.0+git.1489432599.165c23f:
  + merge upstream master (0c2f5f7214d2410a7519f88e65ed5273d6480227)
    including fix for upstream issue#18694 "ceph-disk activate for partition
    failing"
* Fri Mar 10 2017 ncutler@suse.com
- Update to version 12.0.0+git.1489159457.410e200:
  + build/ops: fix Group strings for library packages
* Fri Mar  3 2017 ncutler@suse.com
- Update to version 12.0.0+git.1488553020.e902441:
  + Recent upstream master (3c0af07629dc661aba84e2fef696339ac7171914)
  + Builds with GCC7 (boo#1025891)
* Wed Feb  8 2017 ncutler@suse.com
- Update to version 11.1.0+git.1486588482.ba197ae:
  + Update to latest upstream master (3d740bd)
  + cmake: added empty RPATH to several executables
  + rocksdb: sync with upstream
* Fri Jan 20 2017 ncutler@suse.com
- Update to version 11.1.0+git.1484919552.9216e9a:
  + Revert "rpm: put distro conditionals around Source0 in spec file"
  + Revert "ceph.spec.in: revert Source0 line to upstream version"
* Fri Jan 20 2017 ncutler@suse.com
- pre_checkin.sh: add logic to remove s390 architectures from ExclusiveArch
  line in ceph-test.spec (rationale: ceph-test is not shipped for s390x)
* Fri Jan 20 2017 ncutler@suse.com
- Update to version 11.1.0+git.1484745543.7b08de5:
  + Update to latest upstream master (36874c8) - significant changes:
  * cmake: Turn libcommon into a shared library (PR#12840)
  * cmake: fix rpath on shared libraries and executables (PR#12927)
  + Fix build failure in ppc64le and s390x, caused by missing
    "-momit-leaf-frame-pointer" gcc option in these architectures:
    + rocksdb: build with ppc64 (PR#12908)
* Tue Jan 17 2017 ncutler@suse.com
- Update to version 11.1.0+git.1484659687.3472421:
  + rpm: tell openSUSE to never clean the spec file
  + Enable ppc64le and s390x builds in SLE
  + rpm: lttng only on x86_64 and aarch64
* Thu Jan  5 2017 jfajerski@suse.com
- Update to version 11.1.0+git.1483528076.d86680e (latest master)
  + Merge branch 'master' into ses5 (Merge: 185bcce798 a7b78620f0) with conflicts:
    conflicts in qa/ where resolved with theirs
    conflict in src/osd/PrimaryLogPG.cc was resolved with picking ours plus a method rename
    int ReplicatedPG::do_extent_cmp -> int PrimaryLogPG::do_extent_cmp
* Tue Dec 13 2016 ncutler@suse.com
- Update to version 11.1.0+git.1481663255.bf42706:
  + Update to upstream 11.1.0 release; for details see
    http://docs.ceph.com/docs/master/release-notes/#v11-1-0-release-candidate
  + move ceph_ver_hack.sh script from build service package to git repo
    (bsc#1015419)
* Tue Nov 29 2016 ncutler@suse.com
- Update to version 11.0.2+git.1480437645.66595d3
  + Update to latest upstream master (boost library is now included in the
    tarball, so the tarball is much larger than before and the build takes
    longer to complete)
  + ceph_ver_hack_sh adaptation (upstream dropped src/make_version script)
  + rocksdb: do not build with --march=native (bsc#1012553)
* Fri Nov 25 2016 ncutler@suse.com
- Update to version 11.0.2+git.1480105120.6b8e9e5:
  + Revert commit 8aee8db140bcbd1ffd2a7b571dbbade10bec9de3 because it
    conflicted with upstream
  + update to latest upstream kraken (11.0.2) - for details, see
    http://ceph.com/releases/kraken-11-0-2-released/
* Mon Sep 12 2016 ncutler@suse.com
- Update to version 11.0.0+git.1473684054.73e4b4a:
  + safe_io: Improve portability by replacing loff_t type usage with off_t.
  +  mon: remove the redundant list swap in paxos commit_proposal
  + msg/EventPoll.h: add override to virtual functions
  + msg/EventKqueue.h: add override to virtual func
  + msg/EventSelect.h: add override to virtual funct
  + ceph-disk: Compatibility fixes for Python 3
  + ceph-disk: Use true integer division in get_dev_size
  + ceph-disk: Fix bug in FileLock
  + ceph-disk: Allow ConfigObj to write in binary mode
  + ceph-disk: Use context manager with FileLock
  + ceph-disk: Use os.path.isabs instead of .startswith('/')
  + ceph-disk: Set space_symlink to the path, not file object
  + ceph-disk: PEP8ify
  + rgw: rgw file fix bug of rgw_lookup can not exact match file name
  + rgw: fix the wrong return value
  + rgw/rgw_coroutine: move WaitContext to .cc file
  + client: pass a mask parameter to path_walk
  + mds/mdstypes: add btime to inode
  + mds/Server: set btime=ctime on creation
  + mds/MDCache: set btime on system inodes
  + include/ceph_features: add FS_BTIME features
  + mds: pass btime in InodeStat MClientReply, if feature is present
  + client: keep btime in Inode and InodeStat
  + ceph: break up ll_getattr into two functions
  + client: move the device bitshift handling macros to Client.h
  + libcephfs: add a ceph_ll_getattrx and ceph_statx
  + libcephfs: add a test for "lazy" statx
  + mds/client: add btime to CapSnap and MClientCaps
  + mds/mdstypes: add change attribute to inode
  + mds/Server: set change_attr to 0 on creation
  + mds/MDCache: set change_attr to 0 on system_inodes
  + include/ceph_features: add FS_CHANGE_ATTR feature
  + mds: pass change_attr in InodeStat MClientReply, if feature is present
  + mds/client: keep change_attr in Inode, CapSnap and MClientCaps
  + mds: ensure that change_attr reflects metadata changes on clients that hold CAP_FILE_EXCL
  + mds/client: bump the change_attr at the appropriate time for files
  + libcephfs: return the change_attr in the statx.stx_version field
  + tests: add a ChangeAttr test
  + mds: make frag_info_t add_dirty() function take a pointer to touched_mtime
  + mds: add change_attr to frag_info_t
  + test: add test for change attribute of directories
  + cephfs: rename ceph_mds_request_head and _args with a _legacy postfix
  + MDS: allow the MDS to accept requests to set the btime
  + client: add the ability to set the btime
  + client: add a ceph_fstatx
  + client: extend the Btime test to cover fstatx as well
  + journal/JournalTrimmer: move C_RemoveSet struct
  + rbd_mirror/ImageSynceThrottler: move struct to .cc
  + libcephfs: add unmount function in cephfs.pyx
  + rgw: fix typo of "minite" to "minute" in rgw_lc.cc
  + rgw/rgw_lc.cc: fix sleep time according to the error message
  + crush: don't normalize input of crush_ln iteratively
  + crush: remove clutter
  + mds: remove max_mds config option
  + vstart.sh: add option to turn on multimds
  + rgw: right parenthesis is missing in radosgw-admin help message on caps
  + SQUASH: client: request AUTH caps on the directory during create if we'll need to check perms locally
  + SQUASH: Revert "mds: ensure that change_attr reflects metadata changes on clients that hold CAP_FILE_EXCL"
  + SQUASH: client: always take a change_attr update from the server if it's newer
  + SQUASH: mds/client: don't get clever with ceph_mds_request_head_legacy encode/decode
  + rgw/rgw_rados.h: remove unneeded class C_Tick
  + SQUASH: client: querying for stx_version field requires getting all shared caps
  + SQUASH: mds/client: add routines to copy to/from ceph_mds_request_head_legacy
  + client: properly set inode number of created inode in replay request
  + test/librbd/fsx: enable exclusive-lock feature in krbd mode
  + os/bluestore/BlueFS: fix async compaction txn
  + scripts/bdev_grep: parse bluefs style extents too
  + SQUASH: client: request all shared caps if ctime was requested
  + os/bluestore/BlueFS: factor unflushed log into runway calculation
  + osd/ReplicatedBackend: move classes to cc file
  + os/bluestore: honour allow-eio flag during read
  + CmakeLists.txt: use LIB_RESOLV instead of resolv.
  + osd/ReplicatedPG: move classes to .cc file
  + librbd: potential double-unwatch of watch handle upon error
  + cls/journal: add async client_update_state method
  + journal: allow to trim journal for "laggy" clients
  + librbd: optionally flag "laggy" journal clients disconnected
  + rbd: new command to disconnect journal client
  + rbd-mirror: decode_client_meta should return false on error
  + rbd-mirror: resync was possible only when image replayer start had succeeded
  + rbd-mirror: stop replay when client is disconnected
  + rbd-mirror: option to automatically resync after journal client disconnect
  + qa/workunits/cephtool/test.sh: fix omision of ceph-command
  + os/bluestore: use global compressor if possible
  + build/ops: fix /etc/os-release parsing in install-deps.sh
  + osd/OSD.cc: remove repeated searching of map
  + test/cephfs: add mount&&unmount test
  + mds: s/used_ions/used_inos/
  + Add dependencies from ceph_smalliobenchrbd on cls_rbd, cls_journal, and cls_lock.
  + ceph_test_objectstore: add SyntheticMatrixSharding
  + ceph_test_objectstore: occasional umount/fsck/mount
  + ceph_test_objectstore: test shards for longer
  + crush/CrushCompiler.cc:884 bug fix: index out of range
  + Makfile: Fix rocksdb error when make dist
  + src/CMakeLists.txt: exclude parts not buildable on FreeBSD
  + src/pybind/CMakeLists.txt: conditionaly build cython tools
  + src/tools/CMakeLists.txt: conditionaly build ceph-client-debug
  + src/test/objectstore/CMakeLists.txt: conditionaly build tests
  + mds: trim null dentries proactively
  + cmake: include(SIMDExt) in src/CMakeLists.txt
  + mds: log path with CDir damage messages
  + hint in extent_alloc code
  + remove wrap argument and handle in wrappers
  + Hint argument in alloc_blocks + test case changes
  + os/bluestore: shard extent map
  + os/bluestore: make nid and blobid allocation less racy
  + os/bluestore: optimize compress_extent_map
  + os/bluestore: fix fsck used_block bitmap
  + os/bluestore: use block_size for allocator unit
  + os/bluestore: make blob_t unused helpers use logical length
  + os/bluestore: instrument big/small writes
  + os/bluestore: instrument transaction count
  + os/bluestore: instrument onode reshard events
  + os/bluestore: dump some stats after fsck
  + os/bluestore: assert shared blob cache cleared on split
  + remove autotools
  + test/objectstore/CMakeLists.txt: fix libaio conditional
  + buffer: clear append_buffer on clear()
  + os/bluestore: tunable prealloc size for ExtentMap inline_bl
  + os/bluestore: don't dirty onode if its size is already at desired offset
  + os/bluestore: remove never reachable asserts
  + os/bluestore: drop unnecessary separator between fields
  + os/bluestore: fix key+name sort wonkiness
  + os/bluestore: encode shard id in single byte
  + os/bluestore: small put_ref cleanup
  + os/bluestore: remove faulted debug hackery
  + os/bluestore: bits for unit tests
  + unittest_bluestore_types: resurrect blob and extent_map unit tests
  + os/bluestore/BlueFS: do not start racing async compaction
  + os/bluestore/BlueFS: fix Dir memory leak
  + buffer: implement buffer::list::reserve(n)
  + os/bluestore: do not waste memory on cached encoded blobs
  + qa/workunits/objectstore: fix test_fuse.sh
  + os/FuseStore: only flush if dirty
  + build: drop dryrun of autogen.sh from run-cmake-check.sh script
  + os/bluestore/BlueFS: For logs of rocksdb & bluefs only use directio.
  + os/bluestore: remove some copy-pastes
  + cmake: make py3 a nice-to-have
  + os/bluestore/BlueFS: only extend extent on same bdev
  + msg/AsyncConnection: add const to mem functions
  + msg/AsyncMessenger: add const to function
  + client/barrier: move C_Block_Sync class to .cc
  + osd/OSD.cc: remove unneeded searching of map
  + Set ARM_CRC_FLAGS from the CRC test rather than ARM_NEON_FLAGS
  + rpm: Moved ceph-client-debug from ceph-base to ceph-test package
  + rpm: Renamed bcond tests flag to make_check
  + rbd-nbd: fix kernel deadlock during teuthology testing
  + rbd-nbd: mask out-of-bounds IO errors caused by image shrink
  + librbd: invalidate cache before trimming image
  + librbd: ignore cache busy errors when shrinking an image
  + librbd: potential seg fault when blacklisting an image client
  + cmake: Use WITH_TESTS flag to guard the build of ceph-test scripts/binaries
  + rpm: Added ceph_test_package bcond flag to control the build of ceph-test package
  + deb: Moved ceph-client-debug from ceph-base to ceph-test package
  + ceph-objectstore-tool: add a way to split filestore directories offline
  + install-deps: exit non-zero when we cannot match distro
  + librbd: possible deadlock if cluster connection closed after image
  + osd/ReplicatedPG: remove class redeclaration
  + librbd: ignore partial refresh error when acquiring exclusive lock
  + osd/OSD.cc: remove unneeded returns
* Fri Sep  9 2016 ncutler@suse.com
- Update to version 11.0.0+git.1473424516.3b8b524:
  + Revert "ceph_disk.main: s/get_dev_size/get_free_partition_size/"
  + Revert "ceph_disk tests/test_prepare: s/get_dev_size/get_free_partition_size/"
  + Revert "ceph_disk tests/test_get_free_partition_size: New unit tests"
  + Revert "ceph_disk tox.ini: add tests/test_get_free_partition_size.py"
  + rpm: put distro conditionals around Source0 in spec file
* Fri Sep  9 2016 ncutler@suse.com
- Update to version 11.0.0+git.1473418476.095f67c:
  + ceph.spec.in: revert Source0 line to upstream version
  + ceph.spec.in: conditionalize %%prep command
* Fri Sep  9 2016 ncutler@suse.com
- ceph.spec.in: enable cephfs_java build unconditionally
- new (merged) commits from upstream master branch:
  + mailmap updates
  + rgw: fix the handling of rgw_swift_url_prefix.
  + rgw: ONLY improve code formatting around RGWRESTMgr.
  + rgw: add support for the crossdomain.xml resource of Swift API.
  + rgw: add support for the healthcheck feature of Swift API.
  + swift /info implementation.
  + rgw: settle /info implementation across other swift-at-root features.
  + compressor: isa-l extension for zlib plugin Signed-off-by: Alyona Kiseleva <akiselyova@mirantis.com>
  + mon: tear down standby replays on MDS rank stop
  + mon/MDSMonitor: move C_Updated class to .cc file
  + rgw_file: fix/update rgw_open flag arguments
  + rgw_file: fix/update rgw_create flag arguments
  + doc: remove btrfs contradiction
  + msg: make async backend default
  + msg/simple: wait dispatch_queue until all pipes closed
  + rgw_file: implement stateless write completion timer
  + rgw_file: add RGW_OPEN_FLAG_STATELESS as a synonym for V3
  + rgw_file:  log on write completion events at level 10
  + rgw file: allow RGWLibFS::write_completion_interval_s to be set in conf
  + osdc/ObjectCacher: move C_ReadFinish, C_RetryRead
  + osdc/Journaler: move C_DelayFlush class to .cc
  + rgw: fix RGWAccessControlPolicy_SWIFT::create return value check error
  + librgw: add API version defines for librgw and rgw_file
  + make-dist/ceph.spec.in: Fix srpm build breakage.
  + ceph_timer: prefer using directive to typedef
  + rgw_file:  explain semantics of RGWFileHandle::commit
  + compressor: Better arch ifdefs for isal code
  + mds/MDSTable: add const to member functions
  + os/bluestore: fix some #includes
  + vstart.sh: -b for bluestore
  + os/bluestore/bluestore_types: make blob_t get_chunk_size const
  + os/bluestore: use Blob const and non-const accessors
  + os/bluestore: avoid reencoding unchanged blobs
  + os/bluestore: decode blobs on demand
  + mds/SnapRealm.h: add const to member functions
  + os/bluestore/bluefs: avoid check "locked" field for newly created file
  + os/bluestore/bluefs: check against locked field during unlink
  + os/bluestore/bluefs: assert refs of file don't underflow
  + os/kstore: kill dead code
  + rgw: remove duplicated calls to getattr
  + debian: should dh_python3 python3-* not python-*
  + pybind: silence -Wsign-compare warning
  + test/ceph_test_msgr: fix -Wsign-compare warnings
  + test/unittest_alloc: fix -Wsign-compare warnings
  + librbd: API methods to directly acquire and release the exclusive lock
  + doc: add graphic for cap bit field
  + mds/MDCache.h: remove unneeded access specifier
  + librbd: skeleton implementation of client-side image cache
  + librbd: blocking parent IO completion no longer required
  + librbd: remove use of owner_lock on IO path
  + Revert "osdc: ObjectCacher flusher might needs additional locks"
  + librbd: support bufferlist payload for AioImageWrite
  + librbd: add internal support for scatter/gather IO
  + librbd: initial integration of ImageWriteback to AioImageRequest
  + librbd: consolidate IO clipping to reusable method
  + librbd: differentiate between image and object cache
  + librbd: C_ImageCacheRead bridge from Context to AioCompletion
  + librbd: integrate image cache hooks into IO path
  + common/Throttle.h: remove unneeded class
  + cmake: fix the tracing header dependencies
  + src/test/bench/CMakeLists.txt: RBD exclude
  + src/CMakeLists.txt: RBD|KVS|FUSE exclude
  + src/librbd/CMakeLists.txt: krbd and secret.c are LINUX dependant
  + src/os/CMakeLists.txt: AIO|FUSE exclude
  + src/test/CMakeLists.txt: RADOSGW|RBD exclude
  + src/test/common/CMakeLists.txt: BLKID exclude
  + install-deps.sh: initial distro detection based on /etc/os-release
  + ceph_test_objectstore: fix ObjectStore/StoreTest.BluestoreStatFSTest/2 on ssd
  + ceph_test_objectstore: disable statfs checks on available space
  + messages/MOSDMap: mark as enlighten OSDMap encoder
  + cmake: remove unused librados_api target
  + cmake: replace Findlttng-ust.cmake with FindLTTngUST.cmake
  + cmake: let librados_api_obj depend on librados-tp
  + os/bluestore: yet another statfs test fix
  + Revert "osd/ReplicatedPG: for sync-read it don't cacl l_osd_op_r_prepare_lat."
  + doc/release-notes: v0.94.9
  + os/bluestore/bluefs: use map to track dirty files
  + os/bluestore/bluefs: update mtime of inode in unified path
  + os/bluestore/bluefs: drop redundant eof check for read_random()
  + os/CMakeLists.txt: undubble kv.cc usage.
  + test,pybind: silence -Wsign-compare warnings
  + test/perf_local: fix -Wmaybe-uninitialized warnings
  + os/bluestore: get rid off "isa-l" type in ZLibCompressor ctor
  + Allow compressor build without YASM
  + script/bdev_grep: update to use hex
  + os/bluestore: improve failed csum debug output
  + librbd: improve image state machine debug log messages
  + librbd: deadlock when replaying journal during image open
  + os/bluestore: end scope of std::hex properly
  + os/bluestore: don't over-gift if bluefs free is smaller than bluestore_bluefs_min
  + os/bluestore: use _setattr for SETATTR
  + os/bluestore: make object existence check robust
  + ceph_test_objectstore: assert umount succeeds
  + ceph_test_objectstore: clean up Rename test a bit
  + ceph_test_objectstore: fix TryMoveRename test
  + os/bluestore: add onode/buffer cache statistics
  + os/bluestore: end scope of std::hex properly
  + cmake: pass -DINTEL* to gf-complete cflags
  + os/bluestore: conditional checking label of bluefs devices
  + src/CMakeLists.txt: -Woverloaded-virtual is already included in -Wall on Clang
  + os/bluestore: don't overwrite type if it does already exist and at desired type
  + os/bluestore: trivial cleanups
  + os/bluestore: replace store with logger in Cache
  + os/bluestore: check iterator before using during fsck
* Mon Aug 29 2016 ncutler@suse.com
- pre_checkin.sh: add Source line for ceph-rpmlintrc
- move Source line for ceph-rpmlintrc from ceph.spec to ceph-test.spec
  (see https://github.com/SUSE/ceph/pull/60 for rationale)
* Mon Aug 29 2016 ncutler@suse.com
- Update to version 11.0.0+git.1472455009.a17726c:
  + ceph.spec.in: drop ceph-rpmlintrc source line
  + ceph.spec.in: drop epoch prefixes
* Sun Aug 28 2016 ncutler@suse.com
- Update to version 11.0.0+git.1472384770.c9f3af8:
  + test/rgw: add --gateways-per-zone to test_multi.py
  + rgw: RGWDataSyncCR fails on errors from RGWListBucketIndexesCR
  + rgw: RGWCoroutinesManager::run returns status of last cr
  + os/bluestore: fix whitespace in bitset apply helper
  + cmake: do not link secret.c if not necessary
  + cmake: do not link against keyutils if not necessary
  + os/bluestore: fsck on mkfs (on by default)
  + os/bluestore: ensure block device size is a multiple of the block size
  + Revert "ceph.spec.in: don't try to package __pycache__ for SUSE"
  + rpm: force creation of Python 3 __pycache__ on SUSE
  + doc: add v0.94.7 changelog
  + doc: add v0.94.8 changelog
  + doc/releases: add v0.94.8 to timeline
  + doc/release-notes: fix v10.2.2 changelog link
  + unittest_bluefs: fix block device sizes
  + doc: do not list all major versions in get-packages.rst
  + doc: add missing PR to hammer 0.94.8 release notes
  + doc: release-notes.rst: move misplaced line
  + doc: fix two broken links in releases.rst
  + doc: add 11.0.0 to releases table
* Sun Aug 28 2016 ncutler@suse.com
- pre_checkin.sh: forward-port insert_line_before() function from
  filesystems:ceph:jewel/ceph version
- README-ceph-test.txt: new file
- ceph-test.spec: add ceph_ver_hack.sh as a source file
* Fri Aug 26 2016 ncutler@suse.com
- Update to version 11.0.0+git.1472202104.8999301:
  + rgw: add deadlock detection to RGWCoroutinesManager::run()
  + src/common/lockdep.cc Reduce logging noise if lockdep is not tested
  + osd: fix updating same_interval_since logic of project_pg_history()
  + osd: drop duplicated sched_scrub during tick()
  + osd: move methods which don't need osd_lock from tick into tick_without_osd_lock()
  + mon/PGMonitor: mark dump_object_stat_sum() as static
  + mon/PGMonitor: calc the %%USED of pool using used/(used+avail)
  + rpm: proper packaging of udev directories
  + LTTng-UST disabled for openSUSE
  + ceph-disk: do not activate device that is not ready
  + osd: update reture type of get_pg_or_queue_for_pg() to PGRef
  + common/WPQ: add sanity check to avoid potential access violation
  + osd/osd_types: kill undefined_shard() method of pg_shard_t
  + release-notes.rst: draft 0.94.8 release notes
  + PG: introduce and maintain upset
  + mon/MonClient: should update sub_sent with sub_new
  + osd: set objecter.osdmap when starts
  + rgw: fix for assertion in RGWMetaSyncCR
  + PG: use upset rather than up for _update_calc_stats
  + rgw: do not try to encode or decode time_t
  + cls_rgw: fix the compiler warning
  + msg/async: fix compiler warnings
  + os/filestore: silence compiling warnings
  + test/rbd: silence compiling warnings
  + rgw: silence a compiling warning
  + msg/async/kqueue: avoid remove nonexist kqueue event
  + librbd: cache was not switching to writeback after first flush
  + mon/OSDMonitor: fix potential division-by-zero error
  + mon/OSDMonitor: get rid of snprintf when formatting output string
  + mon/OSDMonitor: avoid duplicated calls when determining osdmap boundary
  + osd/OSDMonitor: avoid duplicated assignment of oldest_map/newest_map
  + osd/OSDMonitor: drop redundant check of exists()
  + mon/PGMonitor: skip scrub checking if we can
  + mon/PGMonitor: drop redundant loading of dumpcontents
  + mon/PGMonitor: fix potential underflow
  + debian: replace SysV rbdmap with systemd service
  + os/bluestore: break down onode vs bnode_map size in log
  + os/bluestore/BlueFS: do direct io by default (not buffered)
  + os/bluestore/BlueFS: rename buffered_io option
  + os/bluestore: add multiple finishers to bluestore
  + os/bluestore: fix decoding hash of bnode
  + cmake: fix unmatched endforeach
  + debian: enable dh_python3 for python3 packages
  + debian: exclude python3* packages in dh_shlibdeps
  + debian: drop python-argparse dependency
  + os/bluestore: fix race condition during get_fs_usage()
  + os/bluestore: use bluefs_max_prefetch for log file prefetch
  + os/bluestore: use hex if we are running out of space
  + os/bluestore: fix assert
  + osd: bail out if transaction size overflows
  + os/filestore/FileJournal: bail out if transaction is too large
  + os/FuseStore: remove unneeded header file
  + os/Memstore.h: add override to virtual functions
  + os/MemStore: move OmapIteratorImpl to cc file
  + os/bluestore: include bluefs space in statfs result
  + common/config_opts: fix comment(radio -> ratio)
  + msg: kill unused macros
  + mon/OSDMonitor: add output field name of average/overload_utilization
  + test/librados: rados_connect() should succeed
  + ceph-osd-prestart.sh: check existence of OSD data directory
  + osd/ReplicatedPG:wipe off param op from generate_subop()
  + ceph-post-file: migrate to RSA SSH keys
  + ceph-post-file: Ignore keys offered by ssh-agent
  + os/Memstore: move PageSetObject class to .cc file
  + yasm-wrapper: dont echo the yasm command line
  + arch/arm.c: remove unnecessary variable read for simplicity
  + rpm: drop obsolete libs-compat metapackage
  + ceph.spec.in: drop trouble-making divider comments
  + rpm: do not unnecessarily spawn shells for scriptlets
  + cls_lock: support updating the lock cookie without releasing the lock
  + librbd: helper state machine to update lock cookie
  + librbd: store exclusive lock cookie instead of recalculating
  + librbd: exclusive lock now supports reacquiring a lost lock
  + librbd: helper state machine for asynchronous watch recovery
  + librbd: integrate asynchronous image rewatch state machine
  + librbd: image state machine now has hooks for lock requests
  + librbd: interlock image refresh and lock operations
  + librbd: remove unused refresh request logic
  + test/common/test_util.cc: FreeBSD does not have distro information
  + README.md: replace package build instructions with tarball instructions
  + doc: fix singleton example in Developer Guide
  + rgw: delete region map after upgrade to zonegroup map
  + rgw: fix period update --commit return error
  + cmake: use PERF_LOCAL_FLAGS only if defined
  + tests: populate /dev/disk/by-partuuid for scsi_debug
  + ceph.spec.in: don't try to package __pycache__ for SUSE
  + doc: fix wrong osdkeepalive name in mount.ceph manpage
  + rados-striper.sh: Use expect_failure and conditional stringmatching
  + Revert "ceph.spec.in: ppc64 build in Tumbleweed only"
  + jerasure: include generic objects in neon jerasure lib (like sse3/4)
* Fri Aug 26 2016 rdias@suse.com
- pre_checkin.sh: fix package files path rewriting
* Tue Aug 23 2016 ncutler@suse.com
- _constraints: tweak values to pick up maximum number of OBS build workers
* Tue Aug 23 2016 rdias@suse.com
- Update to version 11.0.0+git.1471969747.79ca12e:
  + cmake: fix declaration position of WITH_TESTS option
* Tue Aug 23 2016 rdias@suse.com
- Update to version 11.0.0+git.1471959548.f013b97:
  + rpm: Renamed bcond tests flag to make_check
  + cmake: Use WITH_TESTS flag to guard the build of ceph-test scripts/binaries
  + rpm: Added ceph_test_package bcond flag to control the build of ceph-test package
* Fri Aug 19 2016 tserong@suse.com
- Update to version 11.0.0+git.1471605408.9203335:
  + ceph.spec.in: don't try to package __pycache__
* Fri Aug 19 2016 tserong@suse.com
- Update to version 11.0.0+git.1471601504.f312e7e:
  + test/libcephfs: add  the necessary judgment
  + test/librados: add ASSERT_EQ & ASSERT_NE judgment
  + rgw: optimize the usage of string.find and some indents
  + rgw: patch manifest to handle explicit objs copy issue
  + rgw: adjust objs when copying obj with explicit_objs set
  + rgw: adjust manifest head object
  + rgw: fix the error return variable in log message
  + rgw: fix trimming object expirer's hints.
  + rgw: fix skipping some objects to delete by RadosGW's object expirer.
  + rgw: ONLY improve code formatting in rgw_object_expirer_core.{cc,h}.
  + os/bluestore: allow csum verification disable on read.
  + os/bluestore: add csum on/off test case
  + os/bluestore: add store statfs parameters to bluestore perf counters
  + os/bluestore: add perf counters for compress/decompress performance measurement
  + tools: fix the core dump when get the crushmap do not exist
  + librbd: request exclusive lock if current owner cannot execute op
  + src/global/pidfile.cc: Assign elements in structures individually
  + rgw: fixes for period puller
  + rgw: for the create_bucket api, if the input creation_time is zero, we should set it to 'now"
  + pybind: Rework rbd/setup.py for PyPI
  + pybind: Add BUILD_DOC env var to rbd/setup.py
  + doc: fix rbd map format in rbd manpage
  + ceph-disk: change ownership of init file to ceph:ceph
  + cmake: Also build Python bindings for Python 3
  + pybind: Make ceph_volume_client's syntax compatible with Python 3 (just so it passes the bytecompilation step)
  + debian: Add packages for Python 3 bindings
  + rpm: Add packages for Python 3 bindings
  + os/bluestore/bluefs_types: fix extent operator<<
  + os/bluestore/BlueFS: do not op_file_update deleted files
  + os/bluestore: print bluefs_extents in hex
  + os/bluestore: do not track bluefs_extents via freelist
  + os/bluestore/BitMapAllocator: align to min_alloc_size on init_rm_free
  + rgw/doc: fix typo and indent.
  + mon/MonDBStore: fix assert which never fires
  + osd/OSDMonitor: count pg primed more precisely
  + doc: replace cluster name with cluster-name to avoid confusing
  + doc: fix typo maximum -> minimal
  + doc: fix command format
  + batch is_allocated bit checks
  + cmake: Move Python detection back outside of pybind
  + doc: format 2 now is the default image format
  + rgw: Rework of s3 v2 local authentication code.
  + rbd: bench io-size should not be larger than image size
  + doc/install: Use https:// for download.ceph.com
  + librbd: fix possible inconsistent state when disabling mirroring
  + os/bluestore/ExtentFreelistManager: move default create out of parent
  + librbd: new journal policy to disable initializing the journal
  + librbd: permit disabling journaling if in corrupt state
  + qa/workunits: support filtering cls_rbd unit test cases
  + os/bluestore/BlueFS: _should_compact_log
  + os/bluestore/BlueFS: _replay(false) to dump log file
  + mon/PGMonitor: move C_Stats struct to cc file
  + client: don't use special faked-up inode for /..
  + client: add a testcase for "/.." handling
  + os/bluestore/BlueFS: add OP_JUMP
  + os/bluestore/BlueFS: allow log position to when doing op_jump
  + os/bluestore/BlueFS: move metadata dump (compaction) into a helper
  + os/bluestore/BlueFS: interface to get bluefs space usage
  + os/bluestore/BlueFS: init in header at decl
  + os/bluestore/BlueFS: assert we never extend log at flush
  + os/bluestore/BlueFS: use hex
  + os/bluestore/BlueFS: Add sync and async compaction
  + os/bluestore/BlueFS: Helper functions for the unit test framework
  + os/bluestore/BlueFS: unit tests for log compaction
  + os/bluestore/BlueFS: Cleanup unused interfaces
  + unittest_bluefs: make flush_3 test device larger
  + bluestore: initialize csum_order properly
  + librbd: fix possible memory leak when image open fails
  + script: improve ceph-release-notes regex
  + rbdmap: specify bash shell interpreter
  + doc: added rbdmap man page to RBD restructured index
  + librbd: always respond to "release lock" request if lock owner
  + rgw: fix radosgw daemon core when reopen logs
  + qa/workunits/rbd: demote/promote image on same cluster
  + rbd-mirror: include tag tid in bootstrap debug log messages
  + librbd: separate journal::TagData predecessor data into new struct
  + librbd: block RPC requests when demoting the image
  + librbd: normalize journal promotion/demotion events
  + rbd-mirror: demote/promote in same cluster results in split-brain
  + rbd-mirror: prevent syncing to non-primary image after failover
  + test: fixed unused function warnings in unittest_rbd_mirror
  + doc: remove the description of deleted options
  + msg/async/Stack: add abstract Stack
  + msg/async: add PosixStack support
  + msg/async/net_handler: let set_socket_options return value
  + msg/async/AsyncConnection: support NetworkStack api instead of posix
  + msg/async/Event: debug event address when dispatching and executing
  + msg/async/Event: remove event wakeup flag
  + msg/async/PosixStack: increase log level
  + msg/async/Stack: disable smart thread spawn now
  + common/ceph_context: add prefork/postfork wathcher support
  + msg/async/Stack: register fork watcher
  + msg/async: allow EventCenter::set_owner reentry
  + msg/async: readd set_priority call
  + msg/async/AsyncConnection: fix _conn_prefix racing when stopped
  + test_async_networkstack: add networkstack tests
  + msg/async/Event: remove global_centers assert
  + test_msgr: ensure wait for ms_dispatch executed
  + mon/OSDMonitor: add sanity check before setting use_gmt_hitset attribute
  + osd/OSDMonitor: drop redundant null check of max_failed_since
  + osd/OSDMonitor: drop redundant check of assert
  + mon/LogMonitor: remove "host" and "fsid" from handle_conf_change()
  + test: gcc 6.1.1 complains about missing include: <random>. 4.8.3 does not complain about it
  + rgw: fix flush_read_list() error msg
  + cmake: Fix mismatched librgw VERSION / SOVERSION
  + cmake: Add -pie to CMAKE_EXE_LINKER_FLAGS
  + rgw_file: restore local definition of RGWLibFS gc interval
  + kv: delete store after pg destructor is called in OSD shutdown.
  + kv: fix iterator invalidation in memdb.
  + kv: fill 'm_key_value' after 'seek_to_first' or 'seek_to_last'
  + kv: fix iterator bug in prev
  + test/store_test: fix incorrect prompt given by stash callback
  + test/store_test: drop redundant transaction of callbacks
  + test/store_test: avoid dynamic allocation of trans
  + cmake: recompile erasure src for different variants
  + rgw ldap:  protect rgw::from_base64 from non-base64 input
  + qa/workunits/rados/test_python.sh: Allow specifying Python executable (through an environment variable)
  + ceph.spec.in: specify local sources
  + ceph.spec.in: ppc64 build in Tumbleweed only
  + ceph.spec.in: add lowmem_builder_override
  + ceph.spec.in: add Prereq: permissions to radosgw package
  + ceph.spec.in: remove vim hints line
  + ceph.spec.in: remove all mentions of epoch
  + ceph_disk.main: s/get_dev_size/get_free_partition_size/
  + ceph_disk tests/test_prepare: s/get_dev_size/get_free_partition_size/
  + ceph_disk tests/test_get_free_partition_size: New unit tests
  + ceph_disk tox.ini: add tests/test_get_free_partition_size.py
  + ceph.spec.in: replace pwdutils dependency with shadow
  + Make systemd-tmpfiles create /var/run/ceph-radosgw at boot
  + rpm: fix ownership of logfiles in %%pre
  + Revert "rbd: update default image features"
  + osd: munge cache-pin ops with data into writesame
  + ceph osd: add support for new op cmpext
  + rpm: make lowmem_builder code much smarter
  + rpm: add procps build dependency
  + rpm: modify optflags to make debuginfos less huge
  + Revert "ceph.spec.in: add lowmem_builder_override"
  + rpm: lean_debug_symbols bcond
  + rpm: use gcc manpage terminology for debug info bcond
  + Revert "Drop any systemd imposed process/thread limits"
  + Revert "systemd: Add systemd sandboxing to services."
  + rpm: be careful about build parallelism
  + rpm: divergent java, ocf conditional builds
  + rpm: fix _with_ocf
  + rpm: drop obsolete libs-compat metapackage
  + rpm: drop obsolete python-ceph-compat metapackage
  + ceph.spec.in: drop ceph-brag and ceph-post-file
  + ceph.spec.in: move cephfs-* fsck tools to ceph-base
  + ceph.spec.in: move ceph-dencoder to ceph-base
  + rpm: Moved ceph-client-debug from ceph-base to ceph-test package
  + rpm: add udev BuildRequires to provide /usr/lib/udev directory
  + rpm: Remove trailing whitespace in usermod command (SUSE)
* Fri Aug 12 2016 tserong@suse.com
- Update to version 11.0.0+git.1470997027.9c9b8a5:
  + doc/radosgw: remove reference of purge-temp.rst
  + doc/radosgw: fix the table formatting
  + doc: silence sphinx warnings
  + global/signal_handler: use sig_str instead of sys_siglist
  + librados: use bufferlist instead of buffer::list
  + cmake: cleanup Findgperftools.cmake
  + cmake: cleanup Findleveldb.cmake
  + cmake: cleanup Findxio.cmake
  + rgw file: remove busy-wait in RGWLibFS::gc()
  + Lowered third example to keep PG count lower.
  + run-make-check.sh: pass args to do_cmake.sh
  + ceph.spec.in: specify local sources
* Fri Aug  5 2016 ncutler@suse.com
- Update to version 11.0.0+git.1470355272.6fed82a:
  + initial fork of SES5
